@@ -6,7 +6,7 @@
 # alone for any other log analyzer.
 # See COPYING.TXT file about AWStats GNU General Public License.
 #-----------------------------------------------------------------------------
-# $Revision: 1.38 $ - $Author: eldy $ - $Date: 2006/10/26 18:53:34 $
+# $Revision: 1.43 $ - $Author: manolamancha $ - $Date: 2010/04/30 12:26:56 $
 
 use strict; no strict "refs";
 #use diagnostics;
@@ -36,7 +36,7 @@ my %TmpDNSLookup = ();
 
 # ---------- Init variables --------
 use vars qw/ $REVISION $VERSION /;
-$REVISION='$Revision: 1.38 $'; $REVISION =~ /\s(.*)\s/; $REVISION=$1;
+$REVISION='$Revision: 1.43 $'; $REVISION =~ /\s(.*)\s/; $REVISION=$1;
 $VERSION="1.2 (build $REVISION)";
 
 use vars qw/ $NBOFLINESFORBENCHMARK /;
@@ -44,9 +44,9 @@ $NBOFLINESFORBENCHMARK=8192;
 
 use vars qw/
 $DIR $PROG $Extension
-$Debug $ShowSteps $AddFileNum $AddFileName
+$Debug $ShowSteps $AddFileNum $AddFileName $LastLogNum $PrintFields
 $MaxNbOfThread $DNSLookup $DNSCache $DirCgi $DirData $DNSLookupAlreadyDone
-$NbOfLinesShowsteps $AFINET $QueueCursor
+$NbOfLinesShowsteps $AFINET $QueueCursor $StopOnFirstEof $IgnoreMissing
 /;
 $DIR='';
 $PROG='';
@@ -55,6 +55,8 @@ $Debug=0;
 $ShowSteps=0;
 $AddFileNum=0;
 $AddFileName=0;
+$LastLogNum=0;
+$PrintFields=0;
 $MaxNbOfThread=0;
 $DNSLookup=0;
 $DNSCache='';
@@ -63,11 +65,14 @@ $DirData='';
 $DNSLookupAlreadyDone=0;
 $NbOfLinesShowsteps=0;
 $AFINET='';
+$StopOnFirstEof=0;
+$IgnoreMissing=0;
 
 # ---------- Init arrays --------
 use vars qw/
 @SkipDNSLookupFor
 @ParamFile
+@Fields
 /;
 # ---------- Init hash arrays --------
 use vars qw/
@@ -218,6 +223,11 @@ sub WriteRecordsReadyInQueue {
 		# Record is ready, we output it.
 		if ($AddFileNum)  { print "$logfilechosen "; }
 		if ($AddFileName) { print "$LogFileToDo{$logfilechosen} "; }
+		# see if we need to dump fields
+		if ($PrintFields && $LastLogNum != $logfilechosen){
+			print($Fields[$logfilechosen]."\n");
+			$LastLogNum = $logfilechosen;
+		}
 		print "$QueueRecords{$QueueCursor}\n";
 		delete $QueueRecords{$QueueCursor};
 		delete $QueueHostsToResolve{$QueueCursor};
@@ -259,6 +269,9 @@ for (0..@ARGV-1) {
 		elsif ($ARGV[$_] =~ /showsteps/i) { $ShowSteps=1; }
 		elsif ($ARGV[$_] =~ /addfilenum/i) { $AddFileNum=1; }
 		elsif ($ARGV[$_] =~ /addfilename/i) { $AddFileName=1; }
+		elsif ($ARGV[$_] =~ /stoponfirsteof/i) { $StopOnFirstEof=1; }
+		elsif ($ARGV[$_] =~ /printfields/i) { $PrintFields=1; }
+		elsif ($ARGV[$_] =~ /ignoremissing/i) { $IgnoreMissing=1; }
 		else { print "Unknown argument $ARGV[$_] ignored\n"; }
 	}
 	else {
@@ -305,14 +318,20 @@ if (scalar @ParamFile == 0) {
 	print "  $PROG.$Extension [options] *.*\n";
 	print "  perl $PROG.$Extension [options] *.* > newfile\n";
 	print "Options:\n";
-	print "  -dnslookup     make a reverse DNS lookup on IP adresses\n";
-	print "  -dnslookup=n   same with a n parallel threads instead of serial requests\n";
-	print "  -dnscache=file make DNS lookup from cache file first before network lookup\n";
-	print "  -showsteps     print on stderr benchmark information every $NBOFLINESFORBENCHMARK lines\n";
-	print "  -addfilenum    if used with several files, file number can be added in first\n";
-	print "  -addfilename   if used with several files, file name can be added in first\n";
-	print "                 field of output file. This can be used to add a cluster id\n";
-	print "                 when log files come from several load balanced computers.\n";
+	print "  -dnslookup      make a reverse DNS lookup on IP adresses\n";
+	print "  -dnslookup=n    same with a n parallel threads instead of serial requests\n";
+	print "  -dnscache=file  make DNS lookup from cache file first before network lookup\n";
+	print "  -showsteps      print on stderr benchmark information every $NBOFLINESFORBENCHMARK lines\n";
+	print "  -addfilenum     if used with several files, file number can be added in first\n";
+	print "  -addfilename    if used with several files, file name can be added in first\n";
+	print "                  field of output file. This can be used to add a cluster id\n";
+	print "                  when log files come from several load balanced computers.\n";
+	print "  -stoponfirsteof Stop processing when any logfile reaches end-of-file.\n";
+	print "  -printfields    For IIS or W3C logs, prints the latest field header for\n";
+	print "                  the currentlog file when switching between log file entries\n";
+	print "                  so that the parsercan automatically determine which fields\n";
+	print "                  are avaiable.\n";
+	print "  -ignoremissing  will not fail if a log file is missing\n";
 	print "\n";
 	
 	print "This runs $PROG in command line to open one or several\n";
@@ -475,12 +494,19 @@ if (scalar keys %LogFileToDo == 0) {
 if ($Debug) { debug("Start of processing ".(scalar keys %LogFileToDo)." log file(s), $MaxNbOfThread threads max"); }
 foreach my $logfilenb (keys %LogFileToDo) {
 	if ($Debug) { debug("Open log file number $logfilenb: \"$LogFileToDo{$logfilenb}\""); }
-	open("LOG$logfilenb","$LogFileToDo{$logfilenb}") || error("Couldn't open log file \"$LogFileToDo{$logfilenb}\" : $!");
+	if ($IgnoreMissing){
+		if (!open("LOG$logfilenb","$LogFileToDo{$logfilenb}")){
+			debug("Couldn't open log file \"$LogFileToDo{$logfilenb}\" : $!");
+			delete $LogFileToDo{$logfilenb};
+		}
+	}else{
+		open("LOG$logfilenb","$LogFileToDo{$logfilenb}") || error("Couldn't open log file \"$LogFileToDo{$logfilenb}\" : $!");
+	}
 	binmode "LOG$logfilenb";	# To avoid pb of corrupted text log files with binary chars.
 }
 
 $QueueCursor=1;
-while (1 == 1)
+STOPONFIRSTEOF: while (1 == 1)
 {
 	# BEGIN Read new record
 	# For each log file if logfilechosen is 0
@@ -499,12 +525,29 @@ while (1 == 1)
 		while (1 == 1) {
 			my $LOG="LOG$logfilenb";
 			$_=<$LOG>;	# Read new line
-			if (! $_) {							# No more records in log file number $logfilenb
+			if (! $_) 
+			{							# No more records in log file number $logfilenb
 				if ($Debug) { debug(" No more records in file number $logfilenb",2); }
 				delete $LogFileToDo{$logfilenb};
+				if ($StopOnFirstEof) 
+				{
+					if ($Debug) { debug("Exiting loop due to EOF of logfile $logfilenb",1); }
+					last STOPONFIRSTEOF;
+				}
 				last;
 			}
-
+		
+			# Get the latest Fields header for printing IIS and W3C logs
+			if ($PrintFields && $_ =~ m/#Fields:/){
+				my $field = $_;
+				# strip whitespace
+				$field =~ s/^\s+|\s+$//g;
+				if (!$Fields[$logfilenb] || $field != $Fields[$logfilenb]){
+					$Fields[$logfilenb] = $field;
+					debug("Found new fields in $logfilenb: $Fields[$logfilenb]");
+				}
+			}
+			
 			$NbOfLinesRead++;
 			chomp $_; s/\r$//;
 
@@ -517,17 +560,28 @@ while (1 == 1)
 			# Check filters
 			#----------------------------------------------------------------------
 
-			# Split DD/Month/YYYY:HH:MM:SS or YYYY-MM-DD HH:MM:SS or MM/DD/YY\tHH:MM:SS
+			# Split YYYY-MM-DD HH:MM:SS
+			#    or DD/Month/YYYY:HH:MM:SS
+			#    or MM/DD/YY\tHH:MM:SS
+			#    or 9999.999
+ 			#    or Month DD HH:MM:SS
 			my $year=0; my $month=0; my $day=0; my $hour=0; my $minute=0; my $second=0;
 			if ($_ =~ /(\d\d\d\d)-(\d\d)-(\d\d)\s(\d\d):(\d\d):(\d\d)/) { $year=$1; $month=$2; $day=$3; $hour=$4; $minute=$5; $second=$6; }
 			elsif ($_ =~ /\[(\d?\d)[\/:\s](\w+)[\/:\s](\d\d\d\d)[\/:\s](\d\d)[\/:\s](\d\d)[\/:\s](\d\d) /) { $year=$3; $month=$2; $day=$1; $hour=$4; $minute=$5; $second=$6; }
-			elsif ($_ =~ /\[\w+ (\w+) (\d?\d) (\d\d)[\/:\s](\d\d)[\/:\s](\d\d) (\d\d\d\d)\]/) { $year=$6; $month=$1; $day=$2; $hour=$3; $minute=$4; $second=$5; }
+			elsif ($_ =~ /\w+ (\w+) {1,2}(\d?\d) (\d\d)[\/:\s](\d\d)[\/:\s](\d\d) (\d\d\d\d)/) { $year=$6; $month=$1; $day=$2; $hour=$3; $minute=$4; $second=$5; }
 			elsif ($_ =~ /^(\d\d\d\d+\.\d\d\d) /)
 			{
 				my $timetime = strftime('%Y-%m-%d-%T', gmtime($1));
 				$timetime =~ /(\d\d\d\d)-(\d\d)-(\d\d)-(\d\d):(\d\d):(\d\d)/;
 				$year=$1; $month=$2; $day=$3; $hour=$4; $minute=$5; $second=$6;
 			}
+ 			elsif ($_ =~ /(\w+)\s\s?(\d?\d) (\d\d):(\d\d):(\d\d) /) {	# Month DD HH:MM:SS
+ 				$month=$1; $day=$2; $hour=$3; $minute=$4; $second=$5;
+ 				if (($monthnum{$month}>$monthnum{$nowmonth}) || ($monthnum{$month}==$monthnum{$nowmonth} &&  $day>$nowday)) {
+ 					$year=$nowyear-1;
+ 				}
+                else { $year=$nowyear; }
+ 			}
 			if (length $day == 1) { $day = "0".$day; }
 
 			if ($monthnum{$month}) { $month=$monthnum{$month}; }	# Change lib month in num month if necessary
