@@ -2,18 +2,20 @@
 #-------------------------------------------------------
 # Save the click done on managed hits into a trace file
 # and return to browser a redirector to tell browser to visit this URL.
-# Ex: <a href="http://athena/cgi-bin/awredir/awredir.pl?tag=TAGFORLOG&url=http://212.43.217.240/%7Eforumgp/forum/list.php3?f=11">XXX</a>
+# Ex: <a href="http://athena/cgi-bin/awredir/awredir.pl?tag=TAGFORLOG&key=ABCDEFGH&url=http://212.43.217.240/%7Eforumgp/forum/list.php3?f=11">XXX</a>
+# Where ABCDEFGH is md5(YOURKEYFORMD5.url)
 #-------------------------------------------------------
 
 #use DBD::mysql;
+use Digest::MD5 qw(md5 md5_hex md5_base64);
 
 
 #-------------------------------------------------------
 # Defines
 #-------------------------------------------------------
 use vars qw/ $REVISION $VERSION /;
-$REVISION='$Revision: 1.6 $'; $REVISION =~ /\s(.*)\s/; $REVISION=$1;
-$VERSION="1.1 (build $REVISION)";
+$REVISION='$Revision: 1.12 $'; $REVISION =~ /\s(.*)\s/; $REVISION=$1;
+$VERSION="1.2 (build $REVISION)";
 
 use vars qw / $DIR $PROG $Extension $DEBUG $DEBUGFILE $REPLOG $DEBUGRESET $SITE $REPCONF /;
 ($DIR=$0) =~ s/([^\/\\]*)$//; ($PROG=$1) =~ s/\.([^\.]*)$//; $Extension=$1;
@@ -27,6 +29,11 @@ $TXTDIR="$DIR/../../../logs";	# Directory where to write tracking file (if TRACE
 $TXTFILE="awredir.trc";			# Tracking file (if TRACEFILE=1)
 $EXCLUDEIP="127.0.0.1";
 
+# Put here a personalised value.
+# If you dont want to use the security key in link to avoid use of awredir by an external web
+# site you can set this to empty string, but warning this is a security hole as everybody
+# can use awredir on your site to redirect to any web site (even non legal web sites). 
+$KEYFORMD5='YOURKEYFORMD5';
 
 #-------------------------------------------------------
 # Functions
@@ -52,6 +59,21 @@ sub error {
     die;
 }
 
+#------------------------------------------------------------------------------
+# Function:     Decode an URL encoded string
+# Parameters:	stringtodecode
+# Input:        None
+# Output:		None
+# Return:		decodedstring
+#--------------------------------------------------------------------
+sub DecodeEncodedString {
+	my $stringtodecode=shift;
+	$stringtodecode =~ s/\+/ /g;
+	$stringtodecode =~ s/%([a-fA-F0-9][a-fA-F0-9])/pack("C", hex($1))/eg;		# Decode encoded URL
+	return $stringtodecode;
+}
+
+
 #-------------------------------------------------------
 # MAIN
 #-------------------------------------------------------
@@ -73,7 +95,7 @@ if (! $ENV{'GATEWAY_INTERFACE'}) {	# Run from command line
 	print "HTML pages from\n";
 	print "<a href=\"http://externalsite/pagelinked\">Link</a>\n";
 	print "to\n";
-	print "<a href=\"http://mysite/cgi-bin/awredir.pl?url=http://externalsite/pagelinked\">Link</a>\n";
+	print "<a href=\"http://mysite/cgi-bin/awredir.pl?key=ABCDEFGH&url=http://externalsite/pagelinked\">Link</a>\n";
 	print "\n";
 	print "For your web visitor, there is no difference. However this allow you to track\n";
 	print "clicks done on links onto your web pages that point to external web sites,\n";
@@ -84,21 +106,37 @@ if (! $ENV{'GATEWAY_INTERFACE'}) {	# Run from command line
 	exit 0;
 }
 
+if ($KEYFORMD5 eq 'YOURKEYFORMD5') {
+        error("Error: You must change value of constant KEYFORMD5 in awredir.pl script.");
+}
+
 # Extract tag
 $Tag='NOTAG';
 if ($ENV{QUERY_STRING} =~ /tag=\"?([^\"&]+)\"?/) { $Tag=$1; }
 
+$Key='NOKEY';
+if ($ENV{QUERY_STRING} =~ /key=\"?([^\"&]+)\"?/) { $Key=$1; }
+
 # Extract url to redirect to
 $Url=$ENV{QUERY_STRING};
 if ($Url =~ /url=\"([^\"]+)\"/) { $Url=$1; }
 elsif ($Url =~ /url=(.+)$/) { $Url=$1; }
+$Url = DecodeEncodedString($Url);
+$UrlParam=$Url;
 
-if ($Url !~ /^\w+:/i) { $Url = "http://".$Url; }
-if (! $Url) {
-	error("Error: Bad use of $PROG. To redirect an URL with $PROG, use the following syntax:<br><i>/cgi-bin/$PROG.pl?url=http://urltogo</i>");
+if (! $UrlParam) {
+        error("Error: Bad use of $PROG. To redirect an URL with $PROG, use the following syntax:<br><i>/cgi-bin/$PROG.pl?url=http://urltogo</i>");
 }
+
+if ($Url !~ /^http/i) { $Url = "http://".$Url; }
 if ($DEBUG) { print LOGFILE "Url=$Url\n"; }
 
+if ($KEYFORMD5 && ($Key ne md5_hex($KEYFORMD5.$UrlParam))) {
+#       error("Error: Bad value for parameter key=".$Key." to allow a redirect to ".$UrlParam." - ".$KEYFORMD5." - ".md5_hex($KEYFORMD5.$UrlParam) );
+        error("Error: Bad value for parameter key=".$Key." to allow a redirect to ".$UrlParam.". Key must be hexadecimal md5(KEYFORMD5.".$UrlParam.") where KEYFORMD5 is value hardcoded into awredir.pl. Note: You can remove use of key by setting KEYFORMD5 to empty string in script awredir.pl");
+}
+
+
 # Get date
 ($nowsec,$nowmin,$nowhour,$nowday,$nowmonth,$nowyear,$nowwday,$nowyday,$nowisdst) = localtime(time);
 if ($nowyear < 100) { $nowyear+=2000; } else { $nowyear+=1900; }
