@@ -3,7 +3,7 @@
 # If you want to add a Browser to extend AWStats database detection capabilities,
 # you must add an entry in BrowsersSearchIDOrder and in BrowsersHashIDLib.
 #-------------------------------------------------------
-# $Revision: 1.60 $ - $Author: eldy $ - $Date: 2008/09/07 14:05:59 $
+# $Revision: 1.65 $ - $Author: eldy $ - $Date: 2009/10/25 11:20:49 $
 
 # 2006-05-15 Sean Carlos http://www.antezeta.com/awstats.html 
 # 				akregator (rss)
@@ -32,28 +32,45 @@
 # Note: Regex IDs are in lower case and ' ' and '+' are changed into '_'
 #-------------------------------------------------------
 @BrowsersSearchIDOrder = (
-# Most frequent standard web browsers are first in this list (except msie, netscape and firefox)
-'chrome',
+# Most frequent standard web browsers are first in this list except the ones hardcoded in awstats.pl:
+# firefox, opera, chrome, safari, konqueror, svn, msie, netscape
+'elinks',
 'firebird',
 'go!zilla',
 'icab',
-'konqueror',
 'links',
 'lynx',
 'omniweb',
-'opera',
 # Other standard web browsers
 '22acidownload',
+'abrowse',
 'aol\-iweng',
 'amaya',
 'amigavoyager',
+'arora',
 'aweb',
+'charon',
+'donzilla',
+'seamonkey',
+'flock',
+'minefield',
 'bonecho',
+'granparadiso',
+'songbird',
+'strata',
+'sylera',
+'kazehakase',
+'prism',
+'icecat',
+'iceape',
+'iceweasel',
+'w3clinemode',
 'bpftp',
 'camino',
 'chimera',
 'cyberdog',
 'dillo',
+'xchaos_arachne',
 'doris',
 'dreamcast',
 'xbox',
@@ -75,6 +92,7 @@
 'ibrowse',
 'intergo',
 'k\-meleon',
+'k\-ninja',
 'linemodebrowser',
 'lotus\-notes',
 'macweb',
@@ -84,15 +102,17 @@
 'netpositive',
 'nutscrape',
 'msfrontpageexpress',
+'contiki',
+'emacs\-w3',
 'phoenix',
 'shiira',               # Must be before safari
-'safari',				# Must be after a lot of others (shiira, chrome)
 'tzgeturl',
 'viking',
 'webfetcher',
 'webexplorer',
 'webmirror',
 'webvcr',
+'qnx\svoyager',
 # Site grabbers
 'teleport',
 'webcapture',
@@ -110,14 +130,17 @@
 'mplayer',
 'nsplayer',
 'qts',
+'quicktime',
 'sonique',
 'uplayer',
 'xaudio',
 'xine',
 'xmms',
+'gstreamer',
 # RSS Readers
 'abilon',
 'aggrevator',
+'aiderss',
 'akregator',
 'applesyndication',
 'betanews_reader',
@@ -167,19 +190,29 @@
 'ericsson',				# Ericsson (must be after sonyericsson)
 'mmef',
 'mspie',
+'vodafone',
 'wapalizer',
 'wapsilon',
+'wap',					# Generic WAP phone (must be after 'wap*')
 'webcollage',
 'up\.',					# Works for UP.Browser and UP.Link
-# PDA/Phonecell I-Mode browsers
+# PDA/Phonecell browsers
+'android',
+'blackberry',
+'cnf2',
 'docomo',
+'ipcheck',
+'iphone',
 'portalmmm',
 # Others (TV)
 'webtv',
+'democracy',
 # Anonymous Proxy Browsers (can be used as grabbers as well...)
 'cjb\.net',
 'ossproxy',
+'smallproxy',
 # Other kind of browsers
+'adobeair',
 'apt',
 'analogx_proxy',
 'gnome\-vfs',
@@ -190,19 +223,22 @@
 'fdm',
 'javaws',
 'wget',
+'fget',
 'chilkat',
 'webdownloader\sfor\sx',
 'w3m',
 'wdg_validator',
+'w3c_validator',
+'jigsaw',
 'webreaper',
 'webzip',
 'staroffice',
 'gnus', 
 'nikto', 
+'download\smaster',
 'microsoft\-webdav\-miniredir', 
 'microsoft\sdata\saccess\sinternet\spublishing\sprovider\scache\smanager',
 'microsoft\sdata\saccess\sinternet\spublishing\sprovider\sdav',
-'microsoft\sdata\saccess\sinternet\spublishing\sprovider\sprotocol\sdiscovery',
 'POE\-Component\-Client\-HTTP',
 'mozilla',				# Must be at end because a lot of browsers contains mozilla in string
 'libwww',				# Must be at end because some browser have both 'browser id' and 'libwww'
@@ -213,33 +249,54 @@
 # List of browser's name ('browser id in lower case', 'browser text')
 #---------------------------------------------------------------
 %BrowsersHashIDLib = (
-# Common web browsers text
+# Common web browsers text, included the ones hard coded in awstats.pl
+# firefox, opera, chrome, safari, konqueror, svn, msie, netscape
+'firefox','Firefox',
+'opera','Opera',
+'chrome','Google Chrome',
+'safari','Safari',
+'konqueror','Konqueror',
+'svn', 'Subversion client', 
 'msie','MS Internet Explorer',
 'netscape','Netscape',
-'firefox','Firefox',
-'svn', 'Subversion client', 
 
-'chrome','Google Chrome',
+'elinks','ELinks',
 'firebird','Firebird (Old Firefox)',
 'go!zilla','Go!Zilla',
 'icab','iCab',
-'konqueror','Konqueror',
 'links','Links',
 'lynx','Lynx',
 'omniweb','OmniWeb',
-'opera','Opera',
 # Other standard web browsers
 '22acidownload','22AciDownload',
-'aol\-iweng','AOL-Iweng',
+'abrowse','ABrowse',
 'amaya','Amaya',
 'amigavoyager','AmigaVoyager',
+'aol\-iweng','AOL-Iweng',
+'arora','Arora',
 'aweb','AWeb',
-'bonecho','<a href="http://www.mozilla.org/projects/bonecho/" title="Browser home page [new window]" target="_blank">BonEcho (Firefox 2.0 development)</a>',
+'charon', 'Charon',
+'donzilla','Donzilla',
+'seamonkey','SeaMonkey',
+'flock','Flock',
+'minefield','Minefield (Firefox 3.0 development)',
+'bonecho','BonEcho (Firefox 2.0 development)',
+'granparadiso','GranParadiso (Firefox 3.0 development)',
+'songbird','Songbird',
+'strata','Strata',
+'sylera','Sylera',
+'kazehakase','Kazehakase',
+'prism','Prism',
+'icecat','GNU IceCat',
+'iceape','GNU IceApe',
+'iceweasel','Iceweasel',
+'w3clinemode','W3CLineMode',
 'bpftp','BPFTP',
 'camino','Camino',
 'chimera','Chimera (Old Camino)',
 'cyberdog','Cyberdog',
 'dillo','Dillo',
+'xchaos_arachne','Arachne',
 'doris','Doris (for Symbian)',
 'dreamcast','Dreamcast',
 'xbox', 'XBoX',
@@ -261,6 +318,7 @@
 'ibrowse','iBrowse',
 'intergo','InterGO',
 'k\-meleon','K-Meleon',
+'k\-ninja','K-Ninja',
 'linemodebrowser','W3C Line Mode Browser',
 'lotus\-notes','Lotus Notes web client',
 'macweb','MacWeb',
@@ -271,14 +329,16 @@
 'nutscrape', 'Nutscrape',
 'msfrontpageexpress','MS FrontPage Express',
 'phoenix','Phoenix',
+'contiki','Contiki',
+'emacs\-w3','Emacs/w3s',
 'shiira','Shiira',
-'safari','Safari',
 'tzgeturl','TzGetURL',
 'viking','Viking',
 'webfetcher','WebFetcher',
 'webexplorer','IBM-WebExplorer',
 'webmirror','WebMirror',
 'webvcr','WebVCR',
+'qnx\svoyager','QNX Voyager',
 # Site grabbers
 'teleport','TelePort Pro',
 'webcapture','Acrobat Webcapture',
@@ -295,15 +355,18 @@
 'mpg123','mpg123 (media player)',
 'mplayer','The Movie Player (media player)',
 'nsplayer','NetShow Player (media player)',
-'qts','Quicktime',
+'qts','QuickTime (media player)',
+'quicktime','QuickTime (media player)',
 'sonique','Sonique (media player)',
 'uplayer','Ultra Player (media player)',
 'xaudio','Some XAudio Engine based MPEG player (media player)',
 'xine','Xine, a free multimedia player (media player)',
 'xmms','XMMS (media player)',
+'gstreamer','GStreamer (media library)',
 # RSS Readers
 'abilon','Abilon (RSS Reader)',
 'aggrevator', 'Aggrevator (RSS Reader)',
+'aiderss', 'AideRSS (RSS Reader)',
 'akregator','<a href="http://akregator.sourceforge.net/" title="Browser home page [new window]" target="_blank">Akregator (RSS Reader)</a>',  
 'applesyndication','<a href="http://www.apple.com/macosx/features/safari/" title="Browser home page [new window]" target="_blank">AppleSyndication (RSS Reader)</a>',
 'betanews_reader','Betanews Reader (RSS Reader)',
@@ -336,7 +399,7 @@
 'shrook', 'Shrook (RSS Reader)',
 'straw', 'Straw (RSS Reader)',
 'syndirella', 'Syndirella (RSS Reader)',
-'vienna', '<a href="http://www.opencommunity.co.uk/vienna2.php" title="Vienna RSS-Reader [new window]" target="_blank">Vienna (RSS Reader)</a>',
+'vienna', '<a href="http://www.vienna-rss.org/" title="Vienna RSS-Reader [new window]" target="_blank">Vienna (RSS Reader)</a>',
 'wizz\srss\snews\sreader','Wizz RSS News Reader (RSS Reader)',
 # PDA/Phonecell browsers
 'alcatel','Alcatel Browser (PDA/Phone browser)',
@@ -353,19 +416,29 @@
 'ericsson','Ericsson Browser (PDA/Phone browser)',			# Must be after SonyEricsson
 'mmef','Microsoft Mobile Explorer (PDA/Phone browser)',
 'mspie','MS Pocket Internet Explorer (PDA/Phone browser)',
+'vodafone','Vodaphone browser (PDA/Phone browser)',
 'wapalizer','WAPalizer (PDA/Phone browser)',
 'wapsilon','WAPsilon (PDA/Phone browser)',
+'wap','Unknown WAP browser (PDA/Phone browser)',			# Generic WAP phone (must be after 'wap*')
 'webcollage','WebCollage (PDA/Phone browser)',
 'up\.','UP.Browser (PDA/Phone browser)',					# Works for UP.Browser and UP.Link
-# PDA/Phonecell I-Mode browsers
+# PDA/Phonecell browsers
+'android','Android browser (PDA/Phone browser)',
+'blackberry','BlackBerry (PDA/Phone browser)',
+'cnf2','Supervision I-Mode ByTel (phone)',
 'docomo','I-Mode phone (PDA/Phone browser)',
+'ipcheck','Supervision IP Check (phone)',
+'iphone','IPhone (PDA/Phone browser)',
 'portalmmm','I-Mode phone (PDA/Phone browser)',
 # Others (TV)
 'webtv','WebTV browser',
+'democracy','Democracy',
 # Anonymous Proxy Browsers (can be used as grabbers as well...)
 'cjb\.net','<a href="http://proxy.cjb.net/" title="Browser home page [new window]" target="_blank">CJB.NET Proxy</a>',
 'ossproxy','<a href="http://www.marketscore.com/FAQ.Aspx" title="OSSProxy home page [new window]" target="_blank">OSSProxy</a>',
+'smallproxy','<a href="http://www.smallproxy.ru/" title="SmallProxy home page [new window]" target="_blank">SmallProxy</a>',
 # Other kind of browsers
+'adobeair','AdobeAir',
 'apt','Debian APT',
 'analogx_proxy','AnalogX Proxy',
 'gnome\-vfs', 'Gnome FileSystem Abstraction library', 
@@ -376,19 +449,22 @@
 'fdm','<a href="http://www.freedownloadmanager.org/" title="Browser home page [new window]" target="_blank">FDM Free Download Manager</a>',
 'javaws','Java Web Start',
 'wget','Wget',
+'fget','FGet',
 'chilkat', 'Chilkat',
 'webdownloader\sfor\sx','Downloader for X',
 'w3m','w3m',
 'wdg_validator','WDG HTML Validator',
+'w3c_validator','W3C Validator',
+'jigsaw','W3C Validator',
 'webreaper','WebReaper',
 'webzip','WebZIP',
 'staroffice','StarOffice',
 'gnus', 'Gnus Network User Services',
 'nikto', 'Nikto Web Scanner', 
+'download\smaster','Download Master',
 'microsoft\-webdav\-miniredir', 'Microsoft Data Access Component Internet Publishing Provider',
 'microsoft\sdata\saccess\sinternet\spublishing\sprovider\scache\smanager', 'Microsoft Data Access Component Internet Publishing Provider Cache Manager',
 'microsoft\sdata\saccess\sinternet\spublishing\sprovider\sdav', 'Microsoft Data Access Component Internet Publishing Provider DAV',
-'microsoft\sdata\saccess\sinternet\spublishing\sprovider\sprotocol\sdiscovery', 'Microsoft Data Access Component Internet Publishing Provider Protocol Discovery',
 'POE\-Component\-Client\-HTTP','HTTP user-agent for POE (portable networking framework for Perl)',
 'mozilla','Mozilla',
 'libwww','LibWWW',
@@ -409,6 +485,8 @@
 'httrack','1',
 'webreaper','1',
 'wget','1',
+'fget','1',
+'download\smaster','1',
 'webdownloader\sfor\sx','1',
 'webzip','1'
 );
@@ -419,25 +497,41 @@
 # file for this browser.
 #---------------------------------------------------------------------------
 %BrowsersHashIcon = (
-# Standard web browsers
+# Common web browsers text, included the ones hard coded in awstats.pl
+# firefox, opera, chrome, safari, konqueror, svn, msie, netscape
+'firefox','firefox',
+'opera','opera',
+'chrome','chrome', 
+'safari','safari',
+'konqueror','konqueror',
+'svn','subversion',
 'msie','msie',
 'netscape','netscape',
-'firefox','firefox',
-'svn','subversion',
-'chrome','chrome', 
+
 'firebird','phoenix',
 'go!zilla','gozilla',
 'icab','icab',
-'konqueror','konqueror',
 'lynx','lynx',
 'omniweb','omniweb',
-'opera','opera',
 # Other standard web browsers
 'amaya','amaya',
 'amigavoyager','amigavoyager',
 'avantbrowser','avant',
 'aweb','aweb',
 'bonecho','firefox',
+'minefield','firefox',
+'granparadiso','firefox',
+'donzilla','mozilla',
+'songbird','mozilla',
+'strata','mozilla',
+'sylera','mozilla',
+'kazehakase','mozilla',
+'prism','mozilla',
+'iceape','mozilla',
+'seamonkey','seamonkey',
+'flock','flock',
+'icecat','icecat',
+'iceweasel','iceweasel',
 'bpftp','bpftp',
 'camino','chimera',
 'chimera','chimera',
@@ -465,7 +559,6 @@
 'ncsa_mosaic','ncsa_mosaic',
 'netpositive','netpositive',
 'phoenix','phoenix',
-'safari','safari',
 # Site grabbers
 'teleport','teleport',
 'webcapture','adobe',
@@ -488,35 +581,10 @@
 'xaudio','mediaplayer',
 'xine','mediaplayer',
 'xmms','mediaplayer',
-# PDA/Phonecell browsers
-'alcatel','pdaphone',				# Alcatel
-'lg\-','pdaphone',                  # LG
-'ericsson','pdaphone',				# Ericsson
-'mot\-','pdaphone',					# Motorola
-'nokia','pdaphone',					# Nokia
-'panasonic','pdaphone',				# Panasonic
-'philips','pdaphone',				# Philips
-'sagem','pdaphone',                 # Sagem
-'samsung','pdaphone',               # Samsung
-'sie\-','pdaphone',                 # SIE
-'sec\-','pdaphone',                 # Sony/Ericsson
-'sonyericsson','pdaphone',			# Sony/Ericsson
-'mmef','pdaphone',
-'mspie','pdaphone',
-'wapalizer','pdaphone',
-'wapsilon','pdaphone',
-'webcollage','pdaphone',
-'up\.','pdaphone',					# Works for UP.Browser and UP.Link
-# PDA/Phonecell I-Mode browsers
-'docomo','pdaphone',
-'portalmmm','pdaphone',
-# Others (TV)
-'webtv','webtv',
-# Anonymous Proxy Browsers (can be used as grabbers as well...)
-'cjb\.net','cjbnet',
 # RSS Readers
 'abilon', 'abilon',
 'aggrevator', 'rss',
+'aiderss', 'rss',
 'akregator', 'rss',
 'applesyndication', 'rss',
 'betanews_reader','rss',
@@ -550,13 +618,47 @@
 'syndirella', 'rss',
 'vienna', 'rss',
 'wizz\srss\snews\sreader','wizz',
+# PDA/Phonecell browsers
+'alcatel','pdaphone',				# Alcatel
+'lg\-','pdaphone',                  # LG
+'ericsson','pdaphone',				# Ericsson
+'mot\-','pdaphone',					# Motorola
+'nokia','pdaphone',					# Nokia
+'panasonic','pdaphone',				# Panasonic
+'philips','pdaphone',				# Philips
+'sagem','pdaphone',                 # Sagem
+'samsung','pdaphone',               # Samsung
+'sie\-','pdaphone',                 # SIE
+'sec\-','pdaphone',                 # Sony/Ericsson
+'sonyericsson','pdaphone',			# Sony/Ericsson
+'mmef','pdaphone',
+'mspie','pdaphone',
+'vodafone','pdaphone',
+'wapalizer','pdaphone',
+'wapsilon','pdaphone',
+'wap','pdaphone',					# Generic WAP phone (must be after 'wap*')
+'webcollage','pdaphone',
+'up\.','pdaphone',					# Works for UP.Browser and UP.Link
+# PDA/Phonecell browsers
+'android','android',
+'blackberry','pdaphone',
+'docomo','pdaphone',
+'iphone','pdaphone',
+'portalmmm','pdaphone',
+# Others (TV)
+'webtv','webtv',
+# Anonymous Proxy Browsers (can be used as grabbers as well...)
+'cjb\.net','cjbnet',
 # Other kind of browsers
+'adobeair','adobe',
 'apt','apt',
 'analogx_proxy','analogx',
 'microsoft\-webdav\-miniredir','frontpage',
 'microsoft\sdata\saccess\sinternet\spublishing\sprovider\scache\smanager','frontpage',
 'microsoft\sdata\saccess\sinternet\spublishing\sprovider\sdav','frontpage',
 'microsoft\sdata\saccess\sinternet\spublishing\sprovider\sprotocol\sdiscovery','frontpage',
+'microsoft\soffice\sprotocol\sdiscovery','frontpage',
+'microsoft\soffice\sexistence\sdiscovery','frontpage',
 'gnome\-vfs', 'gnome', 
 'neon','neon', 
 'javaws','java',
