@@ -3,7 +3,7 @@
 # If you want to add a Browser to extend AWStats database detection capabilities,
 # you must add an entry in BrowsersSearchIDOrder and in BrowsersHashIDLib.
 #-------------------------------------------------------
-# $Revision: 1.7 $ - $Author: eldy $ - $Date: 2008/09/07 14:05:59 $
+# $Revision: 1.12 $ - $Author: eldy $ - $Date: 2009/10/25 11:20:49 $
 
 # Originale version by malu
 # 2006-05-15 Sean Carlos http://www.antezeta.com/awstats.html 
@@ -22,6 +22,7 @@
 #				Potu Rss-Reader http://www.potu.com/
 #				OSSProxy http://www.marketscore.com/FAQ.Aspx
 
+		
 #package AWSUA;
 
 
@@ -32,28 +33,45 @@
 # Note: Regex IDs are in lower case and ' ' and '+' are changed into '_'
 #-------------------------------------------------------
 @BrowsersSearchIDOrder = (
-# Most frequent standard web browsers are first in this list (except msie, netscape and firefox)
-'chrome',
+# Most frequent standard web browsers are first in this list except the ones hardcoded in awstats.pl:
+# firefox, opera, chrome, safari, konqueror, svn, msie, netscape
+'elinks',
 'firebird',
 'go!zilla',
 'icab',
-'konqueror',
 'links',
 'lynx',
 'omniweb',
-'opera',
 # Other standard web browsers
 '22acidownload',
+'abrowse',
 'aol\-iweng',
 'amaya',
 'amigavoyager',
+'arora',
 'aweb',
+'charon',
+'donzilla',
+'seamonkey',
+'flock',
+'minefield',
 'bonecho',
+'granparadiso',
+'songbird',
+'strata',
+'sylera',
+'kazehakase',
+'prism',
+'icecat',
+'iceape',
+'iceweasel',
+'w3clinemode',
 'bpftp',
 'camino',
 'chimera',
 'cyberdog',
 'dillo',
+'xchaos_arachne',
 'doris',
 'dreamcast',
 'xbox',
@@ -75,6 +93,7 @@
 'ibrowse',
 'intergo',
 'k\-meleon',
+'k\-ninja',
 'linemodebrowser',
 'lotus\-notes',
 'macweb',
@@ -84,15 +103,17 @@
 'netpositive',
 'nutscrape',
 'msfrontpageexpress',
+'contiki',
+'emacs\-w3',
 'phoenix',
 'shiira',               # Must be before safari
-'safari',				# Must be after a lot of others (shiira, chrome)
 'tzgeturl',
 'viking',
 'webfetcher',
 'webexplorer',
 'webmirror',
 'webvcr',
+'qnx\svoyager',
 # Site grabbers
 'teleport',
 'webcapture',
@@ -110,14 +131,17 @@
 'mplayer',
 'nsplayer',
 'qts',
+'quicktime',
 'sonique',
 'uplayer',
 'xaudio',
 'xine',
 'xmms',
+'gstreamer',
 # RSS Readers
 'abilon',
-'aggrevator', 
+'aggrevator',
+'aiderss',
 'akregator',
 'applesyndication',
 'betanews_reader',
@@ -267,6 +291,13 @@
 'nokia7200',
 'nokia7600',
 'nokia7610',
+'nokia5310',
+'nokia6300',
+'nokia6131',
+'nokia5200',
+'nokia7370',
+'nokia5610',
+'nokian70',
 'opwv\-sdk',
 'panasonic\-gad35',
 'panasonic\-gad67',
@@ -315,7 +346,7 @@
 'samsung\-sgh\-a400',
 'samsung\-sgh\-a800',
 'samsung\-sgh\-n100',
-'samsung\-sgh\-n400_up',
+'samsung\-sgh\-n400',
 'samsung\-sgh\-n500',
 'samsung\-sgh\-n600',
 'samsung\-sgh\-n620',
@@ -326,7 +357,6 @@
 'samsung\-sgh\-t100',
 'samsung\-sgh\-t400',
 'samsung\-sgh\-v200',
-'samsung_sgh\-x100',
 'samsung\-sgh\-e100',
 'samsung\-sgh\-e708',
 'samsung\-sgh\-e800',
@@ -548,17 +578,26 @@
 'n21i',
 'n22i',
 'ts21i',
-# PDA/Phonecell I-Mode browsers
-'docomo',
-'portalmmm',
-'ipcheck',
+'wap',					# Generic WAP phone (must be after 'wap*')
+'webcollage',
+'up\.',					# Works for UP.Browser and UP.Link
+# PDA/Phonecell browsers
+'android',
+'blackberry',
 'cnf2',
+'docomo',
+'ipcheck',
+'iphone',
+'portalmmm',
 # Others (TV)
 'webtv',
+'democracy',
 # Anonymous Proxy Browsers (can be used as grabbers as well...)
 'cjb\.net',
 'ossproxy',
+'smallproxy',
 # Other kind of browsers
+'adobeair',
 'apt',
 'analogx_proxy',
 'gnome\-vfs',
@@ -569,19 +608,22 @@
 'fdm',
 'javaws',
 'wget',
+'fget',
 'chilkat',
 'webdownloader\sfor\sx',
 'w3m',
 'wdg_validator',
+'w3c_validator',
+'jigsaw',
 'webreaper',
 'webzip',
 'staroffice',
-'gnus',
-'nikto',
-'microsoft\-webdav\-miniredir',
+'gnus', 
+'nikto', 
+'download\smaster',
+'microsoft\-webdav\-miniredir', 
 'microsoft\sdata\saccess\sinternet\spublishing\sprovider\scache\smanager',
 'microsoft\sdata\saccess\sinternet\spublishing\sprovider\sdav',
-'microsoft\sdata\saccess\sinternet\spublishing\sprovider\sprotocol\sdiscovery',
 'POE\-Component\-Client\-HTTP',
 'mozilla',				# Must be at end because a lot of browsers contains mozilla in string
 'libwww',				# Must be at end because some browser have both 'browser id' and 'libwww'
@@ -592,33 +634,54 @@
 # List of browser's name ('browser id in lower case', 'browser text')
 #---------------------------------------------------------------
 %BrowsersHashIDLib = (
-# Common web browsers text
+# Common web browsers text, included the ones hard coded in awstats.pl
+# firefox, opera, chrome, safari, konqueror, svn, msie, netscape
+'firefox','Firefox',
+'opera','Opera',
+'chrome','Google Chrome',
+'safari','Safari',
+'konqueror','Konqueror',
+'svn', 'Subversion client', 
 'msie','MS Internet Explorer',
 'netscape','Netscape',
-'firefox','Firefox',
-'svn', 'Subversion client', 
 
-'chrome','Google Chrome',
+'elinks','ELinks',
 'firebird','Firebird (Old Firefox)',
 'go!zilla','Go!Zilla',
 'icab','iCab',
-'konqueror','Konqueror',
 'links','Links',
 'lynx','Lynx',
 'omniweb','OmniWeb',
-'opera','Opera',
 # Other standard web browsers
 '22acidownload','22AciDownload',
-'aol\-iweng','AOL-Iweng',
+'abrowse','ABrowse',
 'amaya','Amaya',
 'amigavoyager','AmigaVoyager',
+'aol\-iweng','AOL-Iweng',
+'arora','Arora',
 'aweb','AWeb',
-'bonecho','<a href="http://www.mozilla.org/projects/bonecho/" title="Browser home page [new window]" target="_blank">BonEcho (Firefox 2.0 development)</a>',
+'charon', 'Charon',
+'donzilla','Donzilla',
+'seamonkey','SeaMonkey',
+'flock','Flock',
+'minefield','Minefield (Firefox 3.0 development)',
+'bonecho','BonEcho (Firefox 2.0 development)',
+'granparadiso','GranParadiso (Firefox 3.0 development)',
+'songbird','Songbird',
+'strata','Strata',
+'sylera','Sylera',
+'kazehakase','Kazehakase',
+'prism','Prism',
+'icecat','GNU IceCat',
+'iceape','GNU IceApe',
+'iceweasel','Iceweasel',
+'w3clinemode','W3CLineMode',
 'bpftp','BPFTP',
 'camino','Camino',
 'chimera','Chimera (Old Camino)',
 'cyberdog','Cyberdog',
 'dillo','Dillo',
+'xchaos_arachne','Arachne',
 'doris','Doris (for Symbian)',
 'dreamcast','Dreamcast',
 'xbox', 'XBoX',
@@ -640,6 +703,7 @@
 'ibrowse','iBrowse',
 'intergo','InterGO',
 'k\-meleon','K-Meleon',
+'k\-ninja','K-Ninja',
 'linemodebrowser','W3C Line Mode Browser',
 'lotus\-notes','Lotus Notes web client',
 'macweb','MacWeb',
@@ -650,14 +714,16 @@
 'nutscrape', 'Nutscrape',
 'msfrontpageexpress','MS FrontPage Express',
 'phoenix','Phoenix',
+'contiki','Contiki',
+'emacs\-w3','Emacs/w3s',
 'shiira','Shiira',
-'safari','Safari',
 'tzgeturl','TzGetURL',
 'viking','Viking',
 'webfetcher','WebFetcher',
 'webexplorer','IBM-WebExplorer',
 'webmirror','WebMirror',
 'webvcr','WebVCR',
+'qnx\svoyager','QNX Voyager',
 # Site grabbers
 'teleport','TelePort Pro',
 'webcapture','Acrobat Webcapture',
@@ -674,15 +740,18 @@
 'mpg123','mpg123 (media player)',
 'mplayer','The Movie Player (media player)',
 'nsplayer','NetShow Player (media player)',
-'qts','Quicktime',
+'qts','QuickTime (media player)',
+'quicktime','QuickTime (media player)',
 'sonique','Sonique (media player)',
 'uplayer','Ultra Player (media player)',
 'xaudio','Some XAudio Engine based MPEG player (media player)',
 'xine','Xine, a free multimedia player (media player)',
 'xmms','XMMS (media player)',
+'gstreamer','GStreamer (media library)',
 # RSS Readers
 'abilon','Abilon (RSS Reader)',
 'aggrevator', 'Aggrevator (RSS Reader)',
+'aiderss', 'AideRSS (RSS Reader)',
 'akregator','<a href="http://akregator.sourceforge.net/" title="Browser home page [new window]" target="_blank">Akregator (RSS Reader)</a>',  
 'applesyndication','<a href="http://www.apple.com/macosx/features/safari/" title="Browser home page [new window]" target="_blank">AppleSyndication (RSS Reader)</a>',
 'betanews_reader','Betanews Reader (RSS Reader)',
@@ -715,7 +784,7 @@
 'shrook', 'Shrook (RSS Reader)',
 'straw', 'Straw (RSS Reader)',
 'syndirella', 'Syndirella (RSS Reader)',
-'vienna', '<a href="http://www.opencommunity.co.uk/vienna2.php" title="Vienna RSS-Reader [new window]" target="_blank">Vienna (RSS Reader)</a>',
+'vienna', '<a href="http://www.vienna-rss.org/" title="Vienna RSS-Reader [new window]" target="_blank">Vienna (RSS Reader)</a>',
 'wizz\srss\snews\sreader','Wizz RSS News Reader (RSS Reader)',
 # PDA/Phonecell browsers
 'alcatel\-be4','Alcatel BE4 (phone)',
@@ -752,7 +821,7 @@
 'mot\-v66m','Motorola V66M (phone)',
 'mot\-v708','Motorola V708 (phone)',
 'mot\-8300','Motorola 8300 (phone)',
-'mot\-a-86','Motorola A86 (phone)',
+'mot\-a\-86','Motorola A86 (phone)',
 'mot\-af','Motorola AF (phone)',
 'mot\-c2','Motorola C2 (phone)',
 'mot\-c350','Motorola C350 (phone)',
@@ -803,7 +872,7 @@
 'nokia6150','Nokia 6150 (phone)',
 'nokia6210','Nokia 6210 (phone)',
 'nokia6250','Nokia 6250 (phone)',
-'nokia6310/','Nokia 6310 (phone)',
+'nokia6310\/','Nokia 6310 (phone)',
 'nokia6310i','Nokia 6310i (phone)',
 'nokia6500','Nokia 6500 (phone)',
 'nokia6510','Nokia 6510 (phone)',
@@ -832,6 +901,13 @@
 'nokia7200','Nokia 7200 (phone)',
 'nokia7600','Nokia 7600 (phone)',
 'nokia7610','Nokia 7610 (phone)',
+'nokia5310','Nokia 5310 (phone)',
+'nokia6300','Nokia 6300 (phone)',
+'nokia6131','Nokia 6131 (phone)',
+'nokia5200','Nokia 5200 (phone)',
+'nokia7370','Nokia 7370 (phone)',
+'nokia5610','Nokia 5610 (phone)',
+'nokian70','Nokia N70 (phone)',
 'opwv\-sdk','openwave sdk (phone)',
 'panasonic\-gad35','Panasonic GD35 (phone)',
 'panasonic\-gad67','panasonic GD67 (phone)',
@@ -891,7 +967,6 @@
 'samsung\-sgh\-t100','Samsung T100 (phone)',
 'samsung\-sgh\-t400','Samsung T400 (phone)',
 'samsung\-sgh\-v200','Samsung V200 (phone)',
-'samsung\_sgh\-x100','Samsung X100 (phone)',
 'samsung\-sgh\-e100','Samsung E100 (phone)',
 'samsung\-sgh\-e708','Samsung E700 (phone)',
 'samsung\-sgh\-e800','Samsung E800 (phone)',
@@ -969,7 +1044,7 @@
 'sonyericssont310','SonyEricsson T310 (phone)',
 'sonyericssont600','SonyEricsson T600 (phone)',
 'sonyericssont610','SonyEricsson T610 (phone)',
-'sonyericssont68/','SonyEricsson T68 (phone)',
+'sonyericssont68\/','SonyEricsson T68 (phone)',
 'sonyericssont68i','SonyEricsson T68i (phone)',
 'sonyericssont620','SonyEricsson T620 (phone)',
 'sonyericssont630','SonyEricsson T630 (phone)',
@@ -1113,40 +1188,52 @@
 'n21i','I-Mode Nec 21i (phone)',
 'n22i','I-Mode Nec 22i (phone)',
 'ts21i','I-Mode Toshiba 21i (phone)',
-# PDA/Phonecell I-Mode browsers
-'docomo','I-Mode phone (PDA/Phone browser)',
-'portalmmm','I-Mode phone (PDA/Phone browser)',
-'ipcheck','Supervision IP Check (phone)',
+'wap','Unknown WAP browser (PDA/Phone browser)',			# Generic WAP phone (must be after 'wap*')
+'webcollage','WebCollage (PDA/Phone browser)',
+'up\.','UP.Browser (PDA/Phone browser)',					# Works for UP.Browser and UP.Link
+# PDA/Phonecell browsers
+'android','Android browser (PDA/Phone browser)',
+'blackberry','BlackBerry (PDA/Phone browser)',
 'cnf2','Supervision I-Mode ByTel (phone)',
+'docomo','I-Mode phone (PDA/Phone browser)',
+'ipcheck','Supervision IP Check (phone)',
+'iphone','IPhone (PDA/Phone browser)',
+'portalmmm','I-Mode phone (PDA/Phone browser)',
 # Others (TV)
 'webtv','WebTV browser',
+'democracy','Democracy',
 # Anonymous Proxy Browsers (can be used as grabbers as well...)
 'cjb\.net','<a href="http://proxy.cjb.net/" title="Browser home page [new window]" target="_blank">CJB.NET Proxy</a>',
 'ossproxy','<a href="http://www.marketscore.com/FAQ.Aspx" title="OSSProxy home page [new window]" target="_blank">OSSProxy</a>',
+'smallproxy','<a href="http://www.smallproxy.ru/" title="SmallProxy home page [new window]" target="_blank">SmallProxy</a>',
 # Other kind of browsers
+'adobeair','AdobeAir',
 'apt','Debian APT',
 'analogx_proxy','AnalogX Proxy',
 'gnome\-vfs', 'Gnome FileSystem Abstraction library', 
-'neon', 'Neon HTTP and WebDAV client library',
+'neon', 'Neon HTTP and WebDAV client library', 
 'curl','Curl',
 'csscheck','WDG CSS Validator',
 'httrack','HTTrack',
 'fdm','<a href="http://www.freedownloadmanager.org/" title="Browser home page [new window]" target="_blank">FDM Free Download Manager</a>',
 'javaws','Java Web Start',
 'wget','Wget',
+'fget','FGet',
 'chilkat', 'Chilkat',
 'webdownloader\sfor\sx','Downloader for X',
 'w3m','w3m',
 'wdg_validator','WDG HTML Validator',
+'w3c_validator','W3C Validator',
+'jigsaw','W3C Validator',
 'webreaper','WebReaper',
 'webzip','WebZIP',
 'staroffice','StarOffice',
 'gnus', 'Gnus Network User Services',
-'nikto', 'Nikto Web Scanner',
+'nikto', 'Nikto Web Scanner', 
+'download\smaster','Download Master',
 'microsoft\-webdav\-miniredir', 'Microsoft Data Access Component Internet Publishing Provider',
 'microsoft\sdata\saccess\sinternet\spublishing\sprovider\scache\smanager', 'Microsoft Data Access Component Internet Publishing Provider Cache Manager',
 'microsoft\sdata\saccess\sinternet\spublishing\sprovider\sdav', 'Microsoft Data Access Component Internet Publishing Provider DAV',
-'microsoft\sdata\saccess\sinternet\spublishing\sprovider\sprotocol\sdiscovery', 'Microsoft Data Access Component Internet Publishing Provider Protocol Discovery',
 'POE\-Component\-Client\-HTTP','HTTP user-agent for POE (portable networking framework for Perl)',
 'mozilla','Mozilla',
 'libwww','LibWWW',
@@ -1167,6 +1254,8 @@
 'httrack','1',
 'webreaper','1',
 'wget','1',
+'fget','1',
+'download\smaster','1',
 'webdownloader\sfor\sx','1',
 'webzip','1'
 );
@@ -1176,26 +1265,42 @@
 # Each Browsers Search ID is associated to a string that is the name of icon
 # file for this browser.
 #---------------------------------------------------------------------------
-%BrowsersHashIcon = (           
-# Standard web browsers
+%BrowsersHashIcon = (
+# Common web browsers text, included the ones hard coded in awstats.pl
+# firefox, opera, chrome, safari, konqueror, svn, msie, netscape
+'firefox','firefox',
+'opera','opera',
+'chrome','chrome', 
+'safari','safari',
+'konqueror','konqueror',
+'svn','subversion',
 'msie','msie',
 'netscape','netscape',
-'firefox','firefox',
-'svn','subversion',
-'chrome','chrome',
+
 'firebird','phoenix',
 'go!zilla','gozilla',
 'icab','icab',
-'konqueror','konqueror',
 'lynx','lynx',
 'omniweb','omniweb',
-'opera','opera',
 # Other standard web browsers
 'amaya','amaya',
 'amigavoyager','amigavoyager',
 'avantbrowser','avant',
 'aweb','aweb',
 'bonecho','firefox',
+'minefield','firefox',
+'granparadiso','firefox',
+'donzilla','mozilla',
+'songbird','mozilla',
+'strata','mozilla',
+'sylera','mozilla',
+'kazehakase','mozilla',
+'prism','mozilla',
+'iceape','mozilla',
+'seamonkey','seamonkey',
+'flock','flock',
+'icecat','icecat',
+'iceweasel','iceweasel',
 'bpftp','bpftp',
 'camino','chimera',
 'chimera','chimera',
@@ -1223,7 +1328,6 @@
 'ncsa_mosaic','ncsa_mosaic',
 'netpositive','netpositive',
 'phoenix','phoenix',
-'safari','safari',
 # Site grabbers
 'teleport','teleport',
 'webcapture','adobe',
@@ -1246,16 +1350,10 @@
 'xaudio','mediaplayer',
 'xine','mediaplayer',
 'xmms','mediaplayer',
-# PDA/Phonecell I-Mode browsers
-'docomo','pdaphone',
-'portalmmm','pdaphone',
-# Others (TV)
-'webtv','webtv',
-# Anonymous Proxy Browsers (can be used as grabbers as well...)
-'cjb\.net','cjbnet',
 # RSS Readers
 'abilon', 'abilon',
 'aggrevator', 'rss',
+'aiderss', 'rss',
 'akregator', 'rss',
 'applesyndication', 'rss',
 'betanews_reader','rss',
@@ -1289,15 +1387,49 @@
 'syndirella', 'rss',
 'vienna', 'rss',
 'wizz\srss\snews\sreader','wizz',
+# PDA/Phonecell browsers
+#'alcatel','pdaphone',				# Alcatel
+#'lg\-','pdaphone',                  # LG
+#'ericsson','pdaphone',				# Ericsson
+#'mot\-','pdaphone',					# Motorola
+#'nokia','pdaphone',					# Nokia
+#'panasonic','pdaphone',				# Panasonic
+#'philips','pdaphone',				# Philips
+#'sagem','pdaphone',                 # Sagem
+#'samsung','pdaphone',               # Samsung
+#'sie\-','pdaphone',                 # SIE
+#'sec\-','pdaphone',                 # Sony/Ericsson
+#'sonyericsson','pdaphone',			# Sony/Ericsson
+#'mmef','pdaphone',
+#'mspie','pdaphone',
+#'vodafone','pdaphone',
+#'wapalizer','pdaphone',
+#'wapsilon','pdaphone',
+'wap','pdaphone',					# Generic WAP phone (must be after 'wap*')
+'webcollage','pdaphone',
+'up\.','pdaphone',					# Works for UP.Browser and UP.Link
+# PDA/Phonecell browsers
+'android','android',
+'blackberry','pdaphone',
+'docomo','pdaphone',
+'iphone','pdaphone',
+'portalmmm','pdaphone',
+# Others (TV)
+'webtv','webtv',
+# Anonymous Proxy Browsers (can be used as grabbers as well...)
+'cjb\.net','cjbnet',
 # Other kind of browsers
+'adobeair','adobe',
 'apt','apt',
 'analogx_proxy','analogx',
 'microsoft\-webdav\-miniredir','frontpage',
 'microsoft\sdata\saccess\sinternet\spublishing\sprovider\scache\smanager','frontpage',
 'microsoft\sdata\saccess\sinternet\spublishing\sprovider\sdav','frontpage',
 'microsoft\sdata\saccess\sinternet\spublishing\sprovider\sprotocol\sdiscovery','frontpage',
-'gnome\-vfs', 'gnome',
-'neon','neon',
+'microsoft\soffice\sprotocol\sdiscovery','frontpage',
+'microsoft\soffice\sexistence\sdiscovery','frontpage',
+'gnome\-vfs', 'gnome', 
+'neon','neon', 
 'javaws','java',
 'webzip','webzip',
 'webreaper','webreaper',
@@ -1347,7 +1479,7 @@
 # MSIE		4.0  	Mozilla/4.0 (compatible; MSIE 5.0; Windows 98; DigExt; KITV4 Wanadoo; KITV5 Wanadoo)
 #
 # -- Gecko Netscape --
-# Netscape	4.05	Mozilla/4.05 [fr]C-SYMPA  (Win95; I)
+# Netscape	4.05	Mozilla/4.05 [fr]C-SYMPA (Win95; I)
 # Netscape	4.7     Mozilla/4.7 [fr] (Win95; I)
 # Netscape	6.0		Mozilla/5.0 (Macintosh; N; PPC; fr-FR; m18) Gecko/20001108 Netscape6/6.0
 # Netscape	7.02	Mozilla/5.0 (Platform; Security; OS-or-CPU; Localization; rv:1.0.2) Gecko/20030208 Netscape/7.02 
