@@ -3,7 +3,7 @@
 # If you want to add MIME types,
 # you must add an entry in MimeFamily and may be MimeHashLib
 #-------------------------------------------------------
-# $Revision: 1.24 $ - $Author: eldy $ - $Date: 2008/10/05 11:25:27 $
+# $Revision: 1.26 $ - $Author: eldy $ - $Date: 2010/03/09 20:59:51 $
 
 
 #package AWSMIME;
@@ -31,7 +31,8 @@
 'xsl',       'Extensible Stylesheet Language file',
 'runtime',   'Binary runtime',
 'library',   'Binary library',
-'swf',       'Macromedia Flash Animation',
+'swf',       'Adobe Flash Animation',
+'flv',       'Adobe Flash Video',
 'dtd',       'Document Type Definition',
 'csv',       'Comma Separated Value file',
 'jnlp',      'Java Web Start launch file',
@@ -42,6 +43,11 @@
 'ttf',       'TrueType scalable font file',
 'fon',       'Font file',
 'pdf',       'Adobe Acrobat file',
+'dotnet',	 'Dot Net Dynamic Script or File',
+'mdb', 		 'MS Database Object',
+'crystal',	 'Crystal Reports data or file',
+'ooffice',	 'Open Office Document',
+'encrypt',	 'Encrypted document',
 );
 
 # MimeHashIcon
@@ -53,9 +59,11 @@
 'txt','text',
 'log','text',
 # HTML Static page
+'chm','html',
 'html','html',
 'htm','html',
 'hdml','html',
+'mht','html',
 'wml','html',
 'wmlp','html',
 'xhtml','html',
@@ -65,8 +73,10 @@
 'sgml','html',
 # HTML Dynamic pages or script
 'asp','script',
-'aspx','script', 
-'asmx','script', 
+'aspx','dotnet', 
+'ashx','dotnet',  
+'asmx','dotnet', 
+'axd', 'dotnet',
 'cfm','script',
 'jsp','script',
 'cgi','script',
@@ -80,6 +90,7 @@
 'shtml','html',
 'tcl','script',
 'xsp','script',
+'rss','rss',
 # Image
 'gif','image',
 'png','image',
@@ -95,17 +106,23 @@
 'wmz','doc',
 'rtf','doc',
 'pdf','pdf',
+'frl','pdf',
 'xls','xls',
 'ppt','ppt',
 'pps','ppt',
-'sxw','other',
-'sxc','other',
-'sxi','other',
-'sxd','other',
+'mso','doc',
+'sxw','ooffice',
+'sxc','ooffice',
+'sxi','ooffice',
+'sxd','ooffice',
+'sxm','ooffice',
+'sxg','ooffice',
 'csv','other',
 'xsl','html',
 'lit','lit',
 'ai','ai',
+'mdb','mdb',
+'rpt','crystal',
 # Package
 'rpm',($LogType eq 'S'?'audio':'archive'),
 'deb','archive',
@@ -114,8 +131,11 @@
 '7z','archive',
 'ace','archive',
 'bz2','archive',
+'cab','archive',
+'emz','archive',
 'gz','archive',
 'jar','archive',
+'lzma','archive',
 'rar','archive',
 'tar','archive',
 'tgz','archive',
@@ -123,19 +143,31 @@
 'z','archive',
 'zip','archive',
 # Audio
+'aac','audio',
+'flac','audio',
 'mp3','audio',
+'oga','audio',
 'ogg','audio',
 'wma','audio',
 'wav','audio',
+'m4a','audio',
+'m3u','audio',
+'asf','audio',
 # Video
 'avi','video',
 'divx','video',
 'mp4','video',
+'m4v','video',
 'mpeg','video',
 'mpg','video',
+'ogv','video',
+'ogx','video',
 'rm','real',
 'swf','flash',
+'flv','flash',
+'f4v','flash',
 'wmv','video',
+'wmf','video',
 'mov','quicktime',
 'qt','quicktime',
 # Web scripts
@@ -151,9 +183,13 @@
 'exe','script',
 'dll','script',
 'jnlp','jnlp',
+'bin', 'library',
 # Fonts
 'ttf','ttf',
 'fon','fon',
+# Encrypted files
+'pgp','encrypt',
+'gpg','encrypt',
 );
 
 
@@ -162,8 +198,10 @@
 'txt','text',
 'log','text',
 # HTML Static page
+'chm','page',
 'html','page',
 'htm','page',
+'mht','page',
 'wml','page',
 'wmlp','page',
 'xhtml','page',
@@ -173,8 +211,10 @@
 'sgml','page',
 # HTML Dynamic pages or script
 'asp','script',
-'aspx','script', 
-'asmx','script', 
+'aspx','dotnet',
+'ashx','dotnet',  
+'asmx','dotnet', 
+'axd', 'dotnet',
 'cfm','script',
 'jsp','script',
 'cgi','script',
@@ -188,6 +228,7 @@
 'shtml','script',
 'tcl','script',
 'xsp','script',
+'rss','rss',
 # Image
 'gif','image',
 'png','image',
@@ -203,17 +244,23 @@
 'doc','document',
 'wmz','document',
 'rtf','document',
+'mso','document',
 'pdf','pdf',
+'frl','pdf',
 'xls','document',
 'ppt','document',
 'pps','document',
-'sxw','document',
-'sxc','document',
-'sxi','document',
-'sxd','document',
+'sxw','ooffice',
+'sxc','ooffice',
+'sxi','ooffice',
+'sxd','ooffice',
+'sxm','ooffice',
+'sxg','ooffice',
 'csv','csv',
 'xsl','xsl',
 'lit','lit',
+'mdb','mdb',
+'rpt','crystal',
 # Package
 'rpm',($LogType eq 'S'?'audio':'package'),
 'deb','package',
@@ -222,8 +269,11 @@
 '7z','archive',
 'ace','archive',
 'bz2','archive',
+'cab','archive',
+'emz','archive',
 'gz','archive',
 'jar','archive',
+'lzma','archive',
 'rar','archive',
 'tar','archive',
 'tgz','archive',
@@ -231,19 +281,31 @@
 'z','archive',
 'zip','archive',
 # Audio
+'aac','audio',
+'flac','audio',
 'mp3','audio',
+'oga','audio',
 'ogg','audio',
 'wav','audio',
 'wma','audio',
+'m4a','audio',
+'m3u','audio',
+'asf','audio',
 # Video
 'avi','video',
 'divx','video',
 'mp4','video',
+'m4v','video',
 'mpeg','video',
 'mpg','video',
+'ogv','video',
+'ogx','video',
 'rm','video',
 'swf','swf',
+'flv','flv',
+'f4v','flv',
 'wmv','video',
+'wmf','video',
 'mov','video',
 'qt','video',
 # Web scripts
@@ -259,9 +321,13 @@
 'exe','runtime',
 'jnlp','jnlp',
 'dll','library',
+'bin', 'library',
 # Font
 'ttf','ttf',
 'fon','fon',
+# Encrypted files
+'pgp','encrypt',
+'gpg','encrypt',
 );
 
 
