@@ -5,7 +5,7 @@
 # SearchEnginesHashLib.
 # An entry if known in SearchEnginesKnownUrl is also welcome.
 #------------------------------------------------------------------------------
-# $Revision: 1.43 $ - $Author: eldy $ - $Date: 2007/06/06 17:14:21 $
+# $Revision: 1.51 $ - $Author: eldy $ - $Date: 2009/12/29 20:40:31 $
 
 # 2005-08-19 Sean Carlos http://www.antezeta.com/awstats.html
 #            added minor italian search engines
@@ -155,6 +155,7 @@
 #------------------------------------------------------------------------------
 @SearchEnginesSearchIDOrder_list1=(
 # Major international search engines
+'google\.[\w.]+/products',
 'base\.google\.',
 'froogle\.google\.',
 'groups\.google\.',
@@ -172,6 +173,7 @@
 '72\.14\.2[0-9]{2}\.104',
 'msn\.',
 'live\.com',
+'bing\.',
 'voila\.',
 'mindset\.research\.yahoo',
 'yahoo\.','(66\.218\.71\.225|216\.109\.117\.135|216\.109\.125\.130|66\.218\.69\.11)',
@@ -285,7 +287,15 @@
 # Minor brazilian search engines
 'engine\.exe', 'miner\.bol\.com\.br',
 # Minor chinese search engines
-'baidu\.com','search\.sina\.com','search\.sohu\.com', 'sogou\.com',
+'\.baidu\.com',     # baidu search portal
+'\.vnet\.cn',       # powered by MSN
+'\.soso\.com',      # powered by Google
+'\.sogou\.com',     # powered by Sohu
+'\.3721\.com',      # powered by Yahoo!
+'iask\.com',        # powered by Sina
+'\.accoona\.com',   # Accoona
+'\.163\.com',       # powered by Google
+'\.zhongsou\.com',  # zhongsou search portal
 # Minor czech search engines
 'atlas\.cz','seznam\.cz','quick\.cz','centrum\.cz','jyxo\.(cz|com)','najdi\.to','redbox\.cz',
 # Minor danish search-engines 
@@ -303,7 +313,7 @@
 # Minor german search engines
 'sucheaol\.aol\.de',
 'fireball\.de','infoseek\.de','suche\d?\.web\.de','[a-z]serv\.rrzn\.uni-hannover\.de',
-'suchen\.abacho\.de','brisbane\.t-online\.de','allesklar\.de','meinestadt\.de',
+'suchen\.abacho\.de','(brisbane|suche)\.t-online\.de','allesklar\.de','meinestadt\.de',
 '212\.227\.33\.241',
 '(161\.58\.227\.204|161\.58\.247\.101|212\.40\.165\.90|213\.133\.108\.202|217\.160\.108\.151|217\.160\.111\.99|217\.160\.131\.108|217\.160\.142\.227|217\.160\.176\.42)',
 'wwweasel\.de',
@@ -334,7 +344,9 @@
 # Minor Portuguese search engines
 'sapo\.pt',
 # Minor swiss search engines
-'search\.ch', 'search\.bluewin\.ch'
+'search\.ch', 'search\.bluewin\.ch',
+# Minor Croatian, Serbian, Macedonian, Bosnian and Herzegovinian search engines
+'pogodak\.'
 );
 @SearchEnginesSearchIDOrder_listgen=(
 # Generic search engines
@@ -362,6 +374,7 @@
 #------------------------------------------------------------------------------
 %SearchEnginesHashID = (
 # Major international search engines
+'google\.[\w.]+/products','google_products',
 'base\.google\.','google_base',
 'froogle\.google\.','google_froogle',
 'groups\.google\.','google_groups',
@@ -379,6 +392,7 @@
 '72\.14\.2[0-9]{2}\.104','google_cache',
 'msn\.','msn',
 'live\.com','live',
+'bing\.','bing',
 'voila\.','voila',
 'mindset\.research\.yahoo','yahoo_mindset',
 'yahoo\.','yahoo','(66\.218\.71\.225|216\.109\.117\.135|216\.109\.125\.130|66\.218\.69\.11)','yahoo',
@@ -491,10 +505,15 @@
 'engine\.exe','engine',
 'miner\.bol\.com\.br','miner',
 # Minor chinese search engines
-'baidu\.com','baidu',
-'search\.sina\.com','sina',
-'search\.sohu\.com','sohu',
-'sogou\.com','sogou',
+'\.baidu\.com','baidu',
+'iask\.com','iask',
+'\.accoona\.com','accoona',
+'\.3721\.com','3721',
+'\.163\.com','netease',
+'\.soso\.com','soso',
+'\.zhongsou\.com','zhongsou',
+'\.vnet\.cn','vnet',
+'\.sogou\.com','sogou',
 # Minor czech search engines
 'atlas\.cz','atlas',
 'seznam\.cz','seznam',
@@ -548,7 +567,7 @@
 'suche\d?\.web\.de','webde',
 '[a-z]serv\.rrzn\.uni-hannover\.de','meta',
 'suchen\.abacho\.de','abacho',
-'brisbane\.t-online\.de','t-online',
+'(brisbane|suche)\.t-online\.de','t-online',
 'allesklar\.de','allesklar',
 'meinestadt\.de','meinestadt',
 '212\.227\.33\.241','metaspinner',
@@ -617,6 +636,8 @@
 # Minor swiss search engines
 'search\.ch','searchch',
 'search\.bluewin\.ch','bluewin',
+# Minor Croatian, Serbian, Macedonian, Bosnian and Herzegovinian search engines
+'pogodak\.','pogodak',
 # Generic search engines
 'search\..*\.\w+','search'
 );
@@ -639,6 +660,7 @@
 'altavista','q=',
 'a9','a9\.com\/', 
 'dmoz','search=',
+'google_products','(p|q|as_p|as_q)=',
 'google_base','(p|q|as_p|as_q)=',
 'google_froogle','(p|q|as_p|as_q)=',
 'google_groups','group\/', # does not work
@@ -648,6 +670,7 @@
 'lycos','query=',
 'msn','q=',
 'live','q=',
+'bing','q=',
 'netscape','search=',
 'tiscali','key=',
 'aol','query=',
@@ -750,9 +773,17 @@
 # Minor brazilian search engines
 'engine','p1=', 'miner','q=',
 # Minor chinese search engines
-'baidu','word=', 'sina', 'word=', 'sohu','word=', 'sogou', 'query=',
+'baidu','(wd|word)=',
+'iask','(w|k)=',
+'accoona','qt=',
+'3721','(p|name)=',
+'netease','q=',
+'soso','q=',
+'zhongsou','(word|w)=',
+'sogou', 'query=',
+'vnet','kw=',
 # Minor czech search engines
-'atlas','searchtext=', 'seznam','w=', 'quick','query=', 'centrum','q=', 'jyxo','s=', 'najdi','dotaz=', 'redbox','srch=',
+'atlas','(searchtext|q)=', 'seznam','(w|q)=', 'quick','query=', 'centrum','q=', 'jyxo','(s|q)=', 'najdi','dotaz=', 'redbox','srch=',
 # Minor danish search engines
 'opasia','q=', 'danielsen','q=', 'sol','q=', 'jubii','soegeord=', 'finddk','words=', 'edderkoppen','query=', 'orbis','search_field=', '1klik','query=', 'ofir','querytext=',
 # Minor dutch search engines
@@ -820,7 +851,9 @@
 'passagen','q=',
 'enirose','q=',
 # Minor swiss search engines
-'searchch', 'q=', 'bluewin', 'qry='
+'searchch', 'q=', 'bluewin', 'qry=',
+# Minor Croatian, Serbian, Macedonian, Bosnian and Herzegovinian search engines
+'pogodak', 'q='
 );
 
 # SearchEnginesKnownUrlNotFound
@@ -834,7 +867,7 @@
 # If no rules are known, WordsToExtractSearchUrl will be used to search keyword parameter
 # If no rules are known and search in WordsToExtractSearchUrl failed, this will be used to clean URL of not keyword parameters.
 #------------------------------------------------------------------------------
-@WordsToExtractSearchUrl= ('ask=','claus=','general=','key=','kw=','keyword=','keywords=','MT=','p=','q=','qr=','qt=','query=','s=','search=','searchText=','string=','su=','txtsearch=','w=');
+@WordsToExtractSearchUrl= ('tn=','ie=','ask=','claus=','general=','key=','kw=','keyword=','keywords=','MT=','p=','q=','qr=','qt=','query=','s=','search=','searchText=','string=','su=','txtsearch=','w=');
 @WordsToCleanSearchUrl= ('act=','annuaire=','btng=','cat=','categoria=','cfg=','cof=','cou=','count=','cp=','dd=','domain=','dt=','dw=','enc=','exec=','geo=','hc=','height=','hits=','hl=','hq=','hs=','id=','kl=','lang=','loc=','lr=','matchmode=','medor=','message=','meta=','mode=','order=','page=','par=','pays=','pg=','pos=','prg=','qc=','refer=','sa=','safe=','sc=','sort=','src=','start=','style=','stype=','sum=','tag=','temp=','theme=','type=','url=','user=','width=','what=','\\.x=','\\.y=','y=','look=');
 
 # SearchEnginesKnownUTFCoding
@@ -858,6 +891,7 @@
 'altavista','<a href="http://www.altavista.com/" title="Search Engine Home Page [new window]" target="_blank">AltaVista</a>',
 'a9', '<a href="http://www.a9.com/" title="Search Engine Home Page [new window]" target="_blank">A9</a>',
 'dmoz','<a href="http://dmoz.org/" title="Search Engine Home Page [new window]" target="_blank">DMOZ</a>',
+'google_products','<a href="http://www.google.com/products" title="Search Engine Home Page [new window]" target="_blank">Google (Products)</a>',
 'google_base','<a href="http://base.google.com/" title="Search Engine Home Page [new window]" target="_blank">Google (Base)</a>',
 'google_froogle','<a href="http://froogle.google.com/" title="Search Engine Home Page [new window]" target="_blank">Froogle (Google)</a>',
 'google_groups','<a href="http://groups.google.com/" title="Search Engine Home Page [new window]" target="_blank">Google (Groups)</a>',
@@ -865,8 +899,9 @@
 'google_cache','<a href="http://www.google.com/help/features.html#cached" title="Search Engine Home Page [new window]" target="_blank">Google (cache)</a>',
 'google','<a href="http://www.google.com/" title="Search Engine Home Page [new window]" target="_blank">Google</a>',
 'lycos','<a href="http://www.lycos.com/" title="Search Engine Home Page [new window]" target="_blank">Lycos</a>',
-'msn','<a href="http://search.msn.com/" title="Search Engine Home Page [new window]" target="_blank">MSN Search</a>',
-'live','<a href="http://www.live.com/" title="Search Engine Home Page [new window]" target="_blank">Windows Live</a>',
+'msn','<a href="http://search.msn.com/" title="Search Engine Home Page [new window]" target="_blank">Microsoft MSN Search</a>',
+'live','<a href="http://www.live.com/" title="Search Engine Home Page [new window]" target="_blank">Microsoft Windows Live</a>',
+'bing','<a href="http://www.bing.com/" title="Search Engine Home Page [new window]" target="_blank">Microsoft Bing</a>',
 'netscape','<a href="http://www.netscape.com/" title="Search Engine Home Page [new window]" target="_blank">Netscape</a>',
 'aol','<a href="http://www.aol.com/" title="Search Engine Home Page [new window]" target="_blank">AOL</a>',
 'terra','<a href="http://www.terra.es/" title="Search Engine Home Page [new window]" target="_blank">Terra</a>',
@@ -969,7 +1004,15 @@
 # Minor brazilian search engines
 'engine','Cade', 'miner','Meta Miner',
 # Minor chinese search engines
-'baidu','Baidu', 'sina','Sina', 'sohu','Sohu', 'sogou','<a href="http://www.sogou.com/" title="Search Engine Home Page [new window]" target="_blank">Sogou</a>',
+'baidu','<a href="http://www.baidu.com/" target="_blank">Baidu</a>',
+'iask','<a href="http://www.iask.com/" target="_blank">Iask</a>',
+'accoona','<a href="http://cn.accoona.com">Accoona</a>',
+'3721','<a href="http://www.3721.com/" target="_blank">3721</a>',
+'netease', '<a href="http://www.163.com/" target="_blank">NetEase</a>',
+'soso','<a href="http://www.soso.com/" target="_blank">SoSo</a>',
+'zhongsou','<a href="http://www.zhongsou.com/" target="_blank">ZhongSou</a>',
+'sogou', '<a href="http://www.sogou.com/" target="_blank">SoGou</a>',
+'vnet','<a href="http://114.vnet.cn/" target="_blank">VNet</a>',
 # Minor czech search engines
 'atlas','Atlas.cz',	'seznam','Seznam', 'quick','Quick.cz', 'centrum','Centrum.cz', 'jyxo','Jyxo.cz', 'najdi','Najdi.to', 'redbox','RedBox.cz',
 # Minor danish search-engines
@@ -1017,7 +1060,7 @@
 'shinyseek\.it','Shinyseek.it',
 'teecnoit','<a href="http://www.teecno.it/" title="Teecno home page [new window]" target="_blank">Teecno</a>',
 # Minor Japanese search engines
-'askjp','<a href="http://www.ask.jp/" title="Search E@SearchEngngine Home Page [new window]" target="_blank">Ask Japan</a>',
+'askjp','<a href="http://www.ask.jp/" title="Search Engine Home Page [new window]" target="_blank">Ask Japan</a>',
 'sagool','<a href="http://sagool.jp/" title="Sagool home page [new window]" target="_blank">Sagool</a>',
 # Minor Norwegian search engines
 'start','start.no', 'eniro','<a href="http://www.eniro.no/" title="Search Engine Home Page [new window]" target="_blank">Eniro</a>',	
@@ -1030,7 +1073,7 @@
 'hogapl','<a href="http://www.hoga.pl/" title="Hoga.pl home page [new window]" target="_blank">Hoga.pl</a>',
 'netsprintpl','<a href="http://www.netsprint.pl/" title="NetSprint.pl home page [new window]" target="_blank">NetSprint.pl</a>',
 'interiapl','<a href="http://www.google.interia.pl/" title="Interia.pl home page [new window]" target="_blank">Interia.pl</a>',
-'katalogonetpl','<a href="http://katalog.onet.pl/" ti@SearchEngtle="Katalog.Onet.pl home page [new window]" target="_blank">Katalog.Onet.pl</a>',
+'katalogonetpl','<a href="http://katalog.onet.pl/" title="Katalog.Onet.pl home page [new window]" target="_blank">Katalog.Onet.pl</a>',
 'o2pl','<a href="http://szukaj2.o2.pl/" title="o2.pl home page [new window]" target="_blank">o2.pl</a>',
 'polskapl','<a href="http://szukaj.polska.pl/" title="Polska home page [new window]" target="_blank">Polska</a>',
 'szukaczpl','<a href="http://www.szukacz.pl/" title="Szukacz home page [new window]" target="_blank">Szukacz</a>',
@@ -1041,11 +1084,13 @@
 'passagen','Evreka',
 'enirose','<a href="http://www.eniro.se/" title="Eniro Sverige home page [new window]" target="_blank">Eniro Sverige</a>',
 # Minor Slovak search engines
-'zoznam','<a href="http://www.zoznam.sk/" Searc Engine home page [new window]" target="_blank">Zoznam</a>',
+'zoznam','<a href="http://www.zoznam.sk/" title="Zoznam search engine home page [new window]" target="_blank">Zoznam</a>',
 # Minor Portuguese search engines
-'sapo','<a href="http://www.sapo.pt/" Searc Engine home page [new window]" target="_blank">Sapo</a>',
+'sapo','<a href="http://www.sapo.pt/" title="Sapo search engine home page [new window]" target="_blank">Sapo</a>',
 # Minor Swiss search engines
 'searchch', 'search.ch', 'bluewin', 'search.bluewin.ch',								
+# Minor Croatian, Serbian, Macedonian, Bosnian and Herzegovinian search engines
+'pogodak','<a href="http://www.pogodak.com" title="Pogodak search engine home page [new window]" target="_blank">Pogodak.com</a>',
 # Generic search engines
 'search','Unknown search engines'
 );
@@ -1082,4 +1127,4 @@
 #}
 #print @SearchEnginesSearchIDOrder_list1." ".@SearchEnginesSearchIDOrder_list2." ".@SearchEnginesSearchIDOrder_listgen;
 
-1;
\ No newline at end of file
+1;
