@@ -6,7 +6,7 @@
 #-----------------------------------------------------------------------------
 # Perl Required Modules: Geo::IP or Geo::IP::PurePerl
 #-----------------------------------------------------------------------------
-# $Revision: 1.13 $ - $Author: eldy $ - $Date: 2008/11/15 16:03:42 $
+# $Revision: 1.18 $ - $Author: eldy $ - $Date: 2010/08/23 21:55:34 $
 
 
 # <-----
@@ -37,6 +37,10 @@ no strict "refs";
 # AND THE NAME OF ALL FUNCTIONS THE PLUGIN MANAGE.
 my $PluginNeedAWStatsVersion="6.2";
 my $PluginHooksFunctions="AddHTMLMenuLink AddHTMLGraph ShowInfoHost SectionInitHashArray SectionProcessIp SectionProcessHostname SectionReadHistory SectionWriteHistory";
+my $PluginName="geoip_org_maxmind";
+my $LoadedOverride=0;
+my $OverrideFile="";
+my %TmpDomainLookup; 
 # ----->
 
 # <-----
@@ -64,9 +68,11 @@ sub Init_geoip_org_maxmind {
     
 	# <-----
 	# ENTER HERE CODE TO DO INIT PLUGIN ACTIONS
-	debug(" Plugin geoip_org_maxmind: InitParams=$InitParams",1);
-   	my ($mode,$datafile)=split(/\s+/,$InitParams,2);
+	debug(" Plugin $PluginName: InitParams=$InitParams",1);
+    my ($mode,$tmpdatafile)=split(/\s+/,$InitParams,2);
+    my ($datafile,$override)=split(/\+/,$tmpdatafile,2);
    	if (! $datafile) { $datafile="GeoIPOrg.dat"; }
+   	else { $datafile =~ s/%20/ /g; }
 	if ($type eq 'geoippureperl') {
 		# With pureperl with always use GEOIP_STANDARD.
 		# GEOIP_MEMORY_CACHE seems to fail with ActiveState
@@ -76,12 +82,15 @@ sub Init_geoip_org_maxmind {
 		if ($mode eq '' || $mode eq 'GEOIP_MEMORY_CACHE')  { $mode=Geo::IP::GEOIP_MEMORY_CACHE(); }
 		else { $mode=Geo::IP::GEOIP_STANDARD(); }
 	}
-	debug(" Plugin geoip_org_maxmind: GeoIP initialized type=$type mode=$mode",1);
+	if ($override){ $override =~ s/%20/ /g; $OverrideFile=$override; }
+	%TmpDomainLookup=();
+	debug(" Plugin $PluginName: GeoIP initialized type=$type mode=$mode",1);
 	if ($type eq 'geoippureperl') {
 		$geoip_org_maxmind = Geo::IP::PurePerl->open($datafile, $mode);
 	} else {
 		$geoip_org_maxmind = Geo::IP->open($datafile, $mode);
 	}
+	$LoadedOverride=0;
 # Fails on some GeoIP version
 # 	debug(" Plugin geoip_org_maxmind: GeoIP initialized database_info=".$geoip_org_maxmind->database_info());
 	# ----->
@@ -100,11 +109,11 @@ sub AddHTMLMenuLink_geoip_org_maxmind {
     my $menulink=$_[2];
     my $menutext=$_[3];
 	# <-----
-	if ($Debug) { debug(" Plugin geoip_org_maxmind: AddHTMLMenuLink"); }
+	if ($Debug) { debug(" Plugin $PluginName: AddHTMLMenuLink"); }
     if ($categ eq 'who') {
-        $menu->{'plugin_geoip_org_maxmind'}=0.5;               # Pos
-        $menulink->{'plugin_geoip_org_maxmind'}=2;           # Type of link
-        $menutext->{'plugin_geoip_org_maxmind'}="Organizations";    # Text
+        $menu->{"plugin_$PluginName"}=0.5;               	# Pos
+        $menulink->{"plugin_$PluginName"}=2;           		# Type of link
+        $menutext->{"plugin_$PluginName"}="Organizations";   # Text
     }
 	# ----->
 	return 0;
@@ -126,7 +135,7 @@ sub AddHTMLGraph_geoip_org_maxmind {
 	my $total_p; my $total_h; my $total_k;
 	my $rest_p; my $rest_h; my $rest_k;
 
-	if ($Debug) { debug(" Plugin geoip_org_maxmind: AddHTMLGraph $categ $menu $menulink $menutext"); }
+	if ($Debug) { debug(" Plugin $PluginName: AddHTMLGraph $categ $menu $menulink $menutext"); }
 	my $title='Organizations';
 	&tab_head("$title",19,0,'org');
 	print "<tr bgcolor=\"#$color_TableBGRowTitle\"><th>Organizations : ".((scalar keys %_org_h)-($_org_h{'unknown'}?1:0))."</th>";
@@ -148,9 +157,9 @@ sub AddHTMLGraph_geoip_org_maxmind {
    		    print "<tr>";
    		    my $org=$key; $org =~ s/_/ /g;
    		    print "<td class=\"aws\">".ucfirst($org)."</td>";
-    		if ($ShowISP =~ /P/i) { print "<td>".($_org_p{$key}?$_org_p{$key}:"&nbsp;")."</td>"; }
+    		if ($ShowISP =~ /P/i) { print "<td>".($_org_p{$key}?Format_Number($_org_p{$key}):"&nbsp;")."</td>"; }
     		if ($ShowISP =~ /P/i) { print "<td>".($_org_p{$key}?"$p_p %":'&nbsp;')."</td>"; }
-    		if ($ShowISP =~ /H/i) { print "<td>".($_org_h{$key}?$_org_h{$key}:"&nbsp;")."</td>"; }
+    		if ($ShowISP =~ /H/i) { print "<td>".($_org_h{$key}?Format_Number($_org_h{$key}):"&nbsp;")."</td>"; }
     		if ($ShowISP =~ /H/i) { print "<td>".($_org_h{$key}?"$p_h %":'&nbsp;')."</td>"; }
     		if ($ShowISP =~ /B/i) { print "<td>".Format_Bytes($_org_k{$key})."</td>"; }
     		if ($ShowISP =~ /L/i) { print "<td>".($_org_p{$key}?Format_Date($_org_l{$key},1):'-')."</td>"; }
@@ -180,9 +189,9 @@ sub AddHTMLGraph_geoip_org_maxmind {
 		if ($TotalHits)  { $p_h=int($rest_h/$TotalHits*1000)/10; }
 		print "<tr>";
 		print "<td class=\"aws\"><span style=\"color: #$color_other\">$Message[2]/$Message[0]</span></td>";
-		if ($ShowISP =~ /P/i) { print "<td>".($rest_p?$rest_p:"&nbsp;")."</td>"; }
+		if ($ShowISP =~ /P/i) { print "<td>".($rest_p?Format_Number($rest_p):"&nbsp;")."</td>"; }
    		if ($ShowISP =~ /P/i) { print "<td>".($rest_p?"$p_p %":'&nbsp;')."</td>"; }
-		if ($ShowISP =~ /H/i) { print "<td>".($rest_h?$rest_h:"&nbsp;")."</td>"; }
+		if ($ShowISP =~ /H/i) { print "<td>".($rest_h?Format_Number($rest_h):"&nbsp;")."</td>"; }
    		if ($ShowISP =~ /H/i) { print "<td>".($rest_h?"$p_h %":'&nbsp;')."</td>"; }
 		if ($ShowISP =~ /B/i) { print "<td>".Format_Bytes($rest_k)."</td>"; }
 		if ($ShowISP =~ /L/i) { print "<td>&nbsp;</td>"; }
@@ -224,7 +233,7 @@ sub ShowInfoHost_geoip_org_maxmind {
     	if ($NewLinkParams) { $NewLinkParams="${NewLinkParams}&"; }
 
 		print "<th width=\"80\">";
-        print "<a href=\"".($ENV{'GATEWAY_INTERFACE'} || !$StaticLinks?XMLEncode("$AWScript?${NewLinkParams}output=plugin_geoip_org_maxmind"):"$PROG$StaticLinks.plugin_geoip_org_maxmind.$StaticExt")."\"$NewLinkTarget>GeoIP<br />Org</a>";
+        print "<a href=\"".($ENV{'GATEWAY_INTERFACE'} || !$StaticLinks?XMLEncode("$AWScript?${NewLinkParams}output=plugin_$PluginName"):"$StaticLinks.plugin_$PluginName.$StaticExt")."\"$NewLinkTarget>GeoIP<br />Org</a>";
         print "</th>";
 	}
 	elsif ($param) {
@@ -240,17 +249,17 @@ sub ShowInfoHost_geoip_org_maxmind {
 		}
 		print "<td>";
 		if ($key && $ip==4) {
-        	my $org;
-        	if ($type eq 'geoippureperl')
+			my $org = TmpLookup_geoip_org_maxmind($param);
+        	if (!$org && $type eq 'geoippureperl')
 			{
         		# Function org_by_addr does not exists in PurePerl but org_by_name do same
         		$org=$geoip_org_maxmind->org_by_name($param) if $geoip_org_maxmind;
         	}
-        	else
+        	elsif(!$org)
         	{
         		$org=$geoip_org_maxmind->org_by_addr($param) if $geoip_org_maxmind;
         	}
-        	if ($Debug) { debug("  Plugin geoip_org_maxmind: GetOrgByIp for $param: [$org]",5); }
+        	if ($Debug) { debug("  Plugin $PluginName: GetOrgByIp for $param: [$org]",5); }
 		    if ($org) {
 		        if (length($org) <= $MAXLENGTH) {
 		            print "$org";
@@ -265,16 +274,16 @@ sub ShowInfoHost_geoip_org_maxmind {
 		    print "<span style=\"color: #$color_other\">$Message[0]</span>";
 		}
 		if (! $key) {
-        	my $org;
-        	if ($type eq 'geoippureperl')
+        	my $org = TmpLookup_geoip_org_maxmind($param);
+        	if (!$org && $type eq 'geoippureperl')
 			{
         		$org=$geoip_org_maxmind->org_by_name($param) if $geoip_org_maxmind;
         	}
-        	else
+        	elsif(!$org)
         	{
         		$org=$geoip_org_maxmind->org_by_name($param) if $geoip_org_maxmind;
         	}
-        	if ($Debug) { debug("  Plugin geoip_org_maxmind: GetOrgByHostname for $param: [$org]",5); }
+        	if ($Debug) { debug("  Plugin $PluginName: GetOrgByHostname for $param: [$org]",5); }
 		    if ($org) {
 		        if (length($org) <= $MAXLENGTH) {
 		            print "$org";
@@ -302,7 +311,7 @@ sub ShowInfoHost_geoip_org_maxmind {
 sub SectionInitHashArray_geoip_org_maxmind {
 #    my $param="$_[0]";
 	# <-----
-	if ($Debug) { debug(" Plugin geoip_org_maxmind: Init_HashArray"); }
+	if ($Debug) { debug(" Plugin $PluginName: Init_HashArray"); }
 	%_org_p = %_org_h = %_org_k = %_org_l =();
 	# ----->
 	return 0;
@@ -316,17 +325,17 @@ sub SectionInitHashArray_geoip_org_maxmind {
 sub SectionProcessIp_geoip_org_maxmind {
     my $param="$_[0]";      # Param must be an IP
 	# <-----
-	my $org;
-	if ($type eq 'geoippureperl')
+	my $org = TmpLookup_geoip_org_maxmind($param);
+	if (!$org && $type eq 'geoippureperl')
 	{
 		# Function org_by_addr does not exists in PurePerl but org_by_name do same
 		$org=$geoip_org_maxmind->org_by_name($param) if $geoip_org_maxmind;
 	}
-	else
+	elsif(!$org)
 	{
 		$org=$geoip_org_maxmind->org_by_addr($param) if $geoip_org_maxmind;
 	}
-	if ($Debug) { debug("  Plugin geoip_org_maxmind: GetOrgByIp for $param: [$org]",5); }
+	if ($Debug) { debug("  Plugin $PluginName: GetOrgByIp for $param: [$org]",5); }
     if ($org) {
         $org =~ s/\s/_/g;
         $_org_h{$org}++;
@@ -346,16 +355,16 @@ sub SectionProcessIp_geoip_org_maxmind {
 sub SectionProcessHostname_geoip_org_maxmind {
     my $param="$_[0]";      # Param must be an IP
 	# <-----
-	my $org;
-	if ($type eq 'geoippureperl')
+	my $org = TmpLookup_geoip_org_maxmind($param);
+	if (!$org && $type eq 'geoippureperl')
 	{
 		$org=$geoip_org_maxmind->org_by_name($param) if $geoip_org_maxmind;
 	}
-	else
+	elsif(!$org)
 	{
 		$org=$geoip_org_maxmind->org_by_name($param) if $geoip_org_maxmind;
 	}
-	if ($Debug) { debug("  Plugin geoip_org_maxmind: GetOrgByHostname for $param: [$org]",5); }
+	if ($Debug) { debug("  Plugin $PluginName: GetOrgByHostname for $param: [$org]",5); }
     if ($org) {
         $org =~ s/\s/_/g;
         $_org_h{$org}++;
@@ -378,7 +387,7 @@ sub SectionReadHistory_geoip_org_maxmind {
     my $xmleb=shift;
 	my $countlines=shift;
 	# <-----
-	if ($Debug) { debug(" Plugin geoip_org_maxmind: Begin of PLUGIN_geoip_org_maxmind section"); }
+	if ($Debug) { debug(" Plugin $PluginName: Begin of PLUGIN_$PluginName section"); }
 	my @field=();
 	my $count=0;my $countloaded=0;
 	do {
@@ -394,9 +403,9 @@ sub SectionReadHistory_geoip_org_maxmind {
 		@field=split(/\s+/,($xmlold?XMLDecodeFromHisto($_):$_));
 		$countlines++;
 	}
-	until ($field[0] eq 'END_PLUGIN_geoip_org_maxmind' || $field[0] eq "${xmleb}END_PLUGIN_geoip_org_maxmind" || ! $_);
-	if ($field[0] ne 'END_PLUGIN_geoip_org_maxmind' && $field[0] ne "${xmleb}END_PLUGIN_geoip_org_maxmind") { error("History file is corrupted (End of section PLUGIN not found).\nRestore a recent backup of this file (data for this month will be restored to backup date), remove it (data for month will be lost), or remove the corrupted section in file (data for at least this section will be lost).","","",1); }
-	if ($Debug) { debug(" Plugin geoip_org_maxmind: End of PLUGIN_geoip_org_maxmind section ($count entries, $countloaded loaded)"); }
+	until ($field[0] eq "END_PLUGIN_$PluginName" || $field[0] eq "${xmleb}END_PLUGIN_$PluginName" || ! $_);
+	if ($field[0] ne "END_PLUGIN_$PluginName" && $field[0] ne "${xmleb}END_PLUGIN_$PluginName") { error("History file is corrupted (End of section PLUGIN not found).\nRestore a recent backup of this file (data for this month will be restored to backup date), remove it (data for month will be lost), or remove the corrupted section in file (data for at least this section will be lost).","","",1); }
+	if ($Debug) { debug(" Plugin $PluginName: End of PLUGIN_$PluginName section ($count entries, $countloaded loaded)"); }
 	# ----->
 	return 0;
 }
@@ -407,14 +416,14 @@ sub SectionReadHistory_geoip_org_maxmind {
 #-----------------------------------------------------------------------------
 sub SectionWriteHistory_geoip_org_maxmind {
     my ($xml,$xmlbb,$xmlbs,$xmlbe,$xmlrb,$xmlrs,$xmlre,$xmleb,$xmlee)=(shift,shift,shift,shift,shift,shift,shift,shift,shift);
-    if ($Debug) { debug(" Plugin geoip_org_maxmind: SectionWriteHistory_geoip_org_maxmind start - ".(scalar keys %_org_h)); }
+    if ($Debug) { debug(" Plugin $PluginName: SectionWriteHistory_$PluginName start - ".(scalar keys %_org_h)); }
 	# <-----
 	print HISTORYTMP "\n";
-	if ($xml) { print HISTORYTMP "<section id='plugin_geoip_org_maxmind'><sortfor>$MAXNBOFSECTIONGIR</sortfor><comment>\n"; }
+	if ($xml) { print HISTORYTMP "<section id='plugin_$PluginName'><sortfor>$MAXNBOFSECTIONGIR</sortfor><comment>\n"; }
 	print HISTORYTMP "# Plugin key - Pages - Hits - Bandwidth - Last access\n";
 	#print HISTORYTMP "# The $MaxNbOfExtra[$extranum] first number of hits are first\n";
 	$ValueInFile{'plugin_geoip_org_maxmind'}=tell HISTORYTMP;
-	print HISTORYTMP "${xmlbb}BEGIN_PLUGIN_geoip_org_maxmind${xmlbs}".(scalar keys %_org_h)."${xmlbe}\n";
+	print HISTORYTMP "${xmlbb}BEGIN_PLUGIN_$PluginName${xmlbs}".(scalar keys %_org_h)."${xmlbe}\n";
 	&BuildKeyList($MAXNBOFSECTIONGIR,1,\%_org_h,\%_org_h);
 	my %keysinkeylist=();
 	foreach (@keylist) {
@@ -431,11 +440,67 @@ sub SectionWriteHistory_geoip_org_maxmind {
 		#my $lastaccess=$_org_l{$_}||'';
 		print HISTORYTMP "${xmlrb}$_${xmlrs}0${xmlrs}", $_org_h{$_}, "${xmlrs}0${xmlrs}0${xmlre}\n"; next;
 	}
-	print HISTORYTMP "${xmleb}END_PLUGIN_geoip_org_maxmind${xmlee}\n";
+	print HISTORYTMP "${xmleb}END_PLUGIN_$PluginName${xmlee}\n";
 	# ----->
 	return 0;
 }
 
+#-----------------------------------------------------------------------------
+# PLUGIN FUNCTION: LoadOverrideFile
+# Attempts to load a comma delimited file that will override the GeoIP database
+# Useful for Intranet records
+# CSV format: IP,"organization"
+#-----------------------------------------------------------------------------
+sub LoadOverrideFile_geoip_org_maxmind{
+	my $filetoload="";
+	if ($OverrideFile){
+		if (!open(GEOIPFILE, $OverrideFile)){
+			debug("Plugin $PluginName: Unable to open override file: $OverrideFile");
+			$LoadedOverride = 1;
+			return;
+		}
+	}else{
+		my $conf = (exists(&Get_Config_Name) ? Get_Config_Name() : $SiteConfig);
+		if ($conf && open(GEOIPFILE,"$DirData/$PluginName.$conf.txt"))	{ $filetoload="$DirData/$PluginName.$conf.txt"; }
+		elsif (open(GEOIPFILE,"$DirData/$PluginName.txt"))	{ $filetoload="$DirData/$PluginName.txt"; }
+		else { debug("No override file \"$DirData/$PluginName.txt\": $!"); }
+	}
+	if ($filetoload)
+	{
+		# This is the fastest way to load with regexp that I know
+		while (<GEOIPFILE>){
+			chomp $_;
+			s/\r//;
+			my @record = split(",", $_);
+			# replace quotes if they were used in the file
+			foreach (@record){ $_ =~ s/"//g; }
+			# store in hash
+			$TmpDomainLookup{$record[0]} = $record[1];
+		}
+		close GEOIPFILE;
+        debug(" Plugin $PluginName: Overload file loaded: ".(scalar keys %TmpDomainLookup)." entries found.");
+	}
+	$LoadedOverride = 1;
+	return;
+}
 
+#-----------------------------------------------------------------------------
+# PLUGIN FUNCTION: TmpLookup
+# Searches the temporary hash for the parameter value and returns the corresponding
+# GEOIP entry
+#-----------------------------------------------------------------------------
+sub TmpLookup_geoip_org_maxmind(){
+	$param = shift;
+	if (!$LoadedOverride){&LoadOverrideFile_geoip_org_maxmind();}
+	#my $val;
+	#if ($geoip_org_maxmind && 
+	#(($type eq 'geoip' && $geoip_org_maxmind->VERSION >= 1.30) || 
+	#  $type eq 'geoippureperl' && $geoip_org_maxmind->VERSION >= 1.17)){
+	#	$val = $TmpDomainLookup{$geoip_org_maxmind->get_ip_address($param)};
+	#}
+    #else {$val = $TmpDomainLookup{$param};}
+    #return $val || '';
+    return $TmpDomainLookup{$param}||'';
+}
 
 1;	# Do not remove this line
